@@ -1,97 +1,45 @@
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1/GPL 2.0/LGPL 2.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is Calendar component utils.
- *
- * The Initial Developer of the Original Code is
- *   Joey Minta <jminta@gmail.com>
- * Portions created by the Initial Developer are Copyright (C) 2006
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *   Philipp Kewisch <mozilla@kewis.ch>
- *   Daniel Boelzle <daniel.boelzle@sun.com>
- *   Berend Cornelius <berend.cornelius@sun.com>
- *   Roman Kaeppeler <rkaeppeler@web.de>
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either the GNU General Public License Version 2 or later (the "GPL"), or
- * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
- * in which case the provisions of the GPL or the LGPL are applicable instead
- * of those above. If you wish to allow use of your version of this file only
- * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the MPL, indicate your
- * decision by deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL or the LGPL. If you do not delete
- * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the MPL, the GPL or the LGPL.
- *
- * ***** END LICENSE BLOCK ***** */
+/* This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 /* This file contains commonly used functions in a centralized place so that
  * various components (and other js scopes) don't need to replicate them. Note
  * that loading this file twice in the same scope will throw errors.
  */
 
-Components.utils.import("resource:///modules/Services.jsm");
+Components.utils.import("resource://gre/modules/Services.jsm");
 
-/**
- * Returns a clean new calIEvent
- *
- * @param aIcalString       (optional) The icalString to read event details from.
- */
-function createEvent(aIcalString) {
-    let event = Components.classes["@mozilla.org/calendar/event;1"]
-                          .createInstance(Components.interfaces.calIEvent);
-    if (aIcalString) {
-        event.icalString = aIcalString;
-    }
-    return event;
+function _calIcalCreator(cid, iid) {
+    return function(icalString) {
+        let thing = Components.classes[cid].createInstance(iid);
+        if (icalString) {
+            thing.icalString = icalString;
+        }
+        return thing;
+    };
 }
 
-/**
- * Returns a clean new calITodo
- *
- * @param aIcalString       (optional) The icalString to read task details from.
- */
-function createTodo(aIcalString) {
-    let todo = Components.classes["@mozilla.org/calendar/todo;1"]
-                         .createInstance(Components.interfaces.calITodo);
-    if (aIcalString) {
-        todo.icalString = aIcalString;
-    }
-    return todo;
-}
+let createEvent = _calIcalCreator("@mozilla.org/calendar/event;1",
+                                  Components.interfaces.calIEvent);
+let createTodo = _calIcalCreator("@mozilla.org/calendar/todo;1",
+                                 Components.interfaces.calITodo);
+let createDateTime  = _calIcalCreator("@mozilla.org/calendar/datetime;1",
+                                      Components.interfaces.calIDateTime);
+let createDuration = _calIcalCreator("@mozilla.org/calendar/duration;1",
+                                     Components.interfaces.calIDuration);
+let createAttendee = _calIcalCreator("@mozilla.org/calendar/attendee;1",
+                                     Components.interfaces.calIAttendee);
+let createAttachment = _calIcalCreator("@mozilla.org/calendar/attachment;1",
+                                       Components.interfaces.calIAttachment);
+let createAlarm = _calIcalCreator("@mozilla.org/calendar/alarm;1",
+                                  Components.interfaces.calIAlarm);
+let createRelation = _calIcalCreator("@mozilla.org/calendar/relation;1",
+                                     Components.interfaces.calIRelation);
+let createRecurrenceDate = _calIcalCreator("@mozilla.org/calendar/recurrence-date;1",
+                                           Components.interfaces.calIRecurrenceDate);
+let createRecurrenceRule = _calIcalCreator("@mozilla.org/calendar/recurrence-rule;1",
+                                           Components.interfaces.calIRecurrenceRule);
 
-/* Returns a clean new calIDateTime */
-function createDateTime(aIcalString) {
-    var dt = Components.classes["@mozilla.org/calendar/datetime;1"]
-                       .createInstance(Components.interfaces.calIDateTime);
-    if (aIcalString) {
-        dt.icalString = aIcalString;
-    }
-    return dt;
-}
-
-/* Returns a clean new calIDuration */
-function createDuration(aIcalString) {
-    var dur = Components.classes["@mozilla.org/calendar/duration;1"]
-                        .createInstance(Components.interfaces.calIDuration);
-    if (aIcalString) {
-        dur.icalString = aIcalString;
-    }
-    return dur;
-}
 /* Returns a clean new calIRecurrenceInfo */
 function createRecurrenceInfo(aItem) {
     var recInfo = Components.classes["@mozilla.org/calendar/recurrence-info;1"].
@@ -100,60 +48,12 @@ function createRecurrenceInfo(aItem) {
     return recInfo;
 }
 
-/* Returns a clean new calIRecurrenceRule */
-function createRecurrenceRule() {
-    return Components.classes["@mozilla.org/calendar/recurrence-rule;1"].
-           createInstance(Components.interfaces.calIRecurrenceRule);
-}
-
-/* Returns a clean new calIRecurrenceRule */
-function createRecurrenceDate() {
-    return Components.classes["@mozilla.org/calendar/recurrence-date;1"].
-           createInstance(Components.interfaces.calIRecurrenceDate);
-}
-
-/* Returns a clean new calIAttendee */
-function createAttendee() {
-    return Components.classes["@mozilla.org/calendar/attendee;1"].
-           createInstance(Components.interfaces.calIAttendee);
-}
-
-/* Returns a clean new calIAttachment */
-function createAttachment() {
-    return Components.classes["@mozilla.org/calendar/attachment;1"].
-           createInstance(Components.interfaces.calIAttachment);
-}
-
-/* Returns a clean new calIAlarm*/
-function createAlarm() {
-    return Components.classes["@mozilla.org/calendar/alarm;1"].
-           createInstance(Components.interfaces.calIAlarm);
-}
-
-/* Returns a clean new calIRelation */
-function createRelation() {
-    return Components.classes["@mozilla.org/calendar/relation;1"].
-           createInstance(Components.interfaces.calIRelation);
-}
-
-/* Shortcut to the console service */
-function getConsoleService() {
-    return Components.classes["@mozilla.org/consoleservice;1"]
-                     .getService(Components.interfaces.nsIConsoleService);
-}
-
 /* Shortcut to the account manager service */
 function getAccountManager() {
     return Components.classes["@mozilla.org/messenger/account-manager;1"]
                      .getService(Components.interfaces.nsIMsgAccountManager);
 }
 
-/* Shortcut to the IO service */
-function getIOService() {
-    return Components.classes["@mozilla.org/network/io-service;1"]
-                     .getService(Components.interfaces.nsIIOService);
-}
-
 /* Shortcut to the calendar-manager service */
 function getCalendarManager() {
     return Components.classes["@mozilla.org/calendar/manager;1"]
@@ -320,9 +220,7 @@ function formatStringForCSSRule(aString) {
  */
 function getCalendarDirectory() {
     if (getCalendarDirectory.mDir === undefined) {
-        var dirSvc = Components.classes["@mozilla.org/file/directory_service;1"]
-                               .getService(Components.interfaces.nsIProperties);
-        var dir = dirSvc.get("ProfD", Components.interfaces.nsILocalFile);
+        var dir = Services.dirsvc.get("ProfD", Components.interfaces.nsILocalFile);
         dir.append("calendar-data");
         if (!dir.exists()) {
             try {
@@ -349,8 +247,9 @@ function getCalendarDirectory() {
 function isCalendarWritable(aCalendar) {
     return (!aCalendar.getProperty("disabled") &&
             !aCalendar.readOnly &&
-            (!getIOService().offline ||
+            (!Services.io.offline ||
              aCalendar.getProperty("cache.enabled") ||
+             aCalendar.getProperty("cache.always") ||
              aCalendar.getProperty("requiresNetwork") === false));
 }
 
@@ -398,7 +297,17 @@ function userCanModifyItem(aItem) {
  * @return              True if there is a match
  */
 function attendeeMatchesAddresses(anAttendee, addresses) {
-    let attId = anAttendee.id.toLowerCase().replace(/^mailto:/, "");
+    let attId = anAttendee.id;
+    if (!attId.match(/^mailto:/i)) {
+        // Looks like its not a normal attendee, possibly urn:uuid:...
+        // Try getting the email through the EMAIL property.
+        let emailProp = anAttendee.getProperty("EMAIL");
+        if (emailProp) {
+            attId = emailProp;
+        }
+    }
+
+    attId = attId.toLowerCase().replace(/^mailto:/, "");
     for each (let address in addresses) {
         if (attId == address.toLowerCase().replace(/^mailto:/, "")) {
             return true;
@@ -463,7 +372,7 @@ function calPrint() {
  * @returns  an nsIURI whose spec is aUriString
  */
 function makeURL(aUriString) {
-    return getIOService().newURI(aUriString, null, null);
+    return Services.io.newURI(aUriString, null, null);
 }
 
 /**
@@ -476,34 +385,6 @@ function now() {
     return d.getInTimezone(calendarDefaultTimezone());
 }
 
-/**
- * Returns a calIDateTime corresponding to a javascript Date.
- *
- * @param aDate     a javascript date
- * @param aTimezone (optional) a timezone that should be enforced
- * @returns         a calIDateTime
- *
- * @warning  Use of this function is strongly discouraged.  calIDateTime should
- *           be used directly whenever possible.
- *           If you pass a timezone, then the passed jsDate's timezone will be ignored,
- *           but only its local time portions are be taken.
- */
-function jsDateToDateTime(aDate, aTimezone) {
-    var newDate = createDateTime();
-    if (aTimezone) {
-        newDate.resetTo(aDate.getFullYear(),
-                        aDate.getMonth(),
-                        aDate.getDate(),
-                        aDate.getHours(),
-                        aDate.getMinutes(),
-                        aDate.getSeconds(),
-                        aTimezone);
-    } else {
-        newDate.jsDate = aDate;
-    }
-    return newDate;
-}
-
 /**
  * Selects an item with id aItemId in the radio group with id aRadioGroupId
  *
@@ -589,8 +470,7 @@ function isToDo(aObject) {
  */
 function getPrefSafe(aPrefName, aDefault) {
     const nsIPrefBranch = Components.interfaces.nsIPrefBranch;
-    const prefB = Components.classes["@mozilla.org/preferences-service;1"]
-                            .getService(nsIPrefBranch);
+    const prefB = Services.prefs;
     // Since bug 193332 does not fix the current branch, calling get*Pref will
     // throw NS_ERROR_UNEXPECTED if clearUserPref() was called and there is no
     // default value. To work around that, catch the exception.
@@ -632,17 +512,15 @@ function setPref(aPrefName, aPrefValue, aPrefType) {
                 break;
         }
     }
-    let prefB = Components.classes["@mozilla.org/preferences-service;1"]
-                          .getService(Components.interfaces.nsIPrefBranch);
     switch (aPrefType) {
         case "BOOL":
-            prefB.setBoolPref(aPrefName, aPrefValue);
+            Services.prefs.setBoolPref(aPrefName, aPrefValue);
             break;
         case "INT":
-            prefB.setIntPref(aPrefName, aPrefValue);
+            Services.prefs.setIntPref(aPrefName, aPrefValue);
             break;
         case "CHAR":
-            prefB.setCharPref(aPrefName, aPrefValue);
+            Services.prefs.setCharPref(aPrefName, aPrefValue);
             break;
     }
 }
@@ -654,12 +532,10 @@ function setPref(aPrefName, aPrefValue, aPrefType) {
  * @param aString     the string to which the preference value should be set
  */
 function setLocalizedPref(aPrefName, aString) {
-    const prefB = Components.classes["@mozilla.org/preferences-service;1"].
-                  getService(Components.interfaces.nsIPrefBranch);
     var str = Components.classes["@mozilla.org/supports-string;1"].
               createInstance(Components.interfaces.nsISupportsString);
     str.data = aString;
-    prefB.setComplexValue(aPrefName, Components.interfaces.nsISupportsString, str);
+    Services.prefs.setComplexValue(aPrefName, Components.interfaces.nsISupportsString, str);
 }
 
 /**
@@ -669,11 +545,9 @@ function setLocalizedPref(aPrefName, aString) {
  * @param aDefault    (optional) the value to return if the pref is undefined
  */
 function getLocalizedPref(aPrefName, aDefault) {
-    const pb2 = Components.classes["@mozilla.org/preferences-service;1"].
-                getService(Components.interfaces.nsIPrefBranch);
     var result;
     try {
-        result = pb2.getComplexValue(aPrefName, Components.interfaces.nsISupportsString).data;
+        result = Services.prefs.getComplexValue(aPrefName, Components.interfaces.nsISupportsString).data;
     } catch(ex) {
         return aDefault;
     }
@@ -686,15 +560,68 @@ function getLocalizedPref(aPrefName, aDefault) {
  * @return array of category names
  */
 function getPrefCategoriesArray() {
-    var categories = getLocalizedPref("calendar.categories.names", null);
+    let categories = getLocalizedPref("calendar.categories.names", null);
+
     // If no categories are configured load a default set from properties file
-    if (!categories || categories == "") {
-        categories = calGetString("categories", "categories2");
-        setLocalizedPref("calendar.categories.names", categories);
+    if (!categories) {
+        categories = setupDefaultCategories();
     }
     return categoriesStringToArray(categories);
 }
 
+/**
+ * Sets up the default categories from the localized string
+ *
+ * @return      The default set of categories as a comma separated string.
+ */
+function setupDefaultCategories() {
+    // First, set up the category names
+    let categories = calGetString("categories", "categories2");
+    setLocalizedPref("calendar.categories.names", categories);
+
+    // Now, initialize the category default colors
+    let categoryArray = categoriesStringToArray(categories);
+    for each (let category in categoryArray) {
+        let prefName = formatStringForCSSRule(category);
+        setPref("calendar.category.color." + prefName,
+                hashColor(category),
+                "CHAR");
+    }
+
+    // Return the list of categories for further processing
+    return categories;
+}
+
+/**
+ * Hash the given string into a color from the color palette of the standard
+ * color picker.
+ *
+ * @param str           The string to hash into a color.
+ * @return              The hashed color.
+ */
+function hashColor(str) {
+    // This is the palette of colors in the current colorpicker implementation.
+    // Unfortunately, there is no easy way to extract these colors from the
+    // binding directly.
+    const colorPalette = ["#FFFFFF", "#FFCCCC", "#FFCC99", "#FFFF99", "#FFFFCC",
+                          "#99FF99", "#99FFFF", "#CCFFFF", "#CCCCFF", "#FFCCFF",
+                          "#CCCCCC", "#FF6666", "#FF9966", "#FFFF66", "#FFFF33",
+                          "#66FF99", "#33FFFF", "#66FFFF", "#9999FF", "#FF99FF",
+                          "#C0C0C0", "#FF0000", "#FF9900", "#FFCC66", "#FFFF00",
+                          "#33FF33", "#66CCCC", "#33CCFF", "#6666CC", "#CC66CC",
+                          "#999999", "#CC0000", "#FF6600", "#FFCC33", "#FFCC00",
+                          "#33CC00", "#00CCCC", "#3366FF", "#6633FF", "#CC33CC",
+                          "#666666", "#990000", "#CC6600", "#CC9933", "#999900",
+                          "#009900", "#339999", "#3333FF", "#6600CC", "#993399",
+                          "#333333", "#660000", "#993300", "#996633", "#666600",
+                          "#006600", "#336666", "#000099", "#333399", "#663366",
+                          "#000000", "#330000", "#663300", "#663333", "#333300",
+                          "#003300", "#003333", "#000066", "#330099", "#330033"];
+
+    let sum = Array.map(str || " ", function(e) e.charCodeAt(0)).reduce(function(a,b) a + b);
+    return colorPalette[sum % colorPalette.length];
+}
+
 /**
  * Convert categories string to list of category names.
  *
@@ -737,18 +664,6 @@ function categoriesArrayToString(aSortedCategoriesArray) {
     return aSortedCategoriesArray.map(escapeComma).join(",");
 }
 
-/**
- * Creates a string bundle.
- *
- * @param bundleURL The bundle URL
- * @return string bundle
- */
-function calGetStringBundle(bundleURL) {
-    let service = Components.classes["@mozilla.org/intl/stringbundle;1"]
-                            .getService(Components.interfaces.nsIStringBundleService);
-    return service.createBundle(bundleURL);
-}
-
 /**
  * Gets the value of a string in a .properties file from the calendar bundle
  *
@@ -764,7 +679,7 @@ function calGetString(aBundleName, aStringName, aParams, aComponent) {
             aComponent = "calendar";
         }
         var propName = "chrome://" + aComponent + "/locale/" + aBundleName + ".properties";
-        var props = calGetStringBundle(propName);
+        var props = Services.strings.createBundle(propName);
 
         if (aParams && aParams.length) {
             return props.formatStringFromName(aStringName, aParams, aParams.length);
@@ -1003,11 +918,9 @@ function setDefaultStartEndHour(aItem, aReferenceDate) {
  *              properties should be logged.
  */
 function LOG(aArg) {
-    var prefB = Components.classes["@mozilla.org/preferences-service;1"].
-                getService(Components.interfaces.nsIPrefBranch);
     var shouldLog = false;
     try {
-        shouldLog = prefB.getBoolPref("calendar.debug.log");
+        shouldLog = Services.prefs.getBoolPref("calendar.debug.log");
     } catch(ex) {}
 
     if (!shouldLog) {
@@ -1028,7 +941,7 @@ function LOG(aArg) {
 
     // xxx todo consider using function debug()
     dump(string + '\n');
-    getConsoleService().logStringMessage(string);
+    Services.console.logStringMessage(string);
 }
 
 /**
@@ -1043,7 +956,7 @@ function WARN(aMessage) {
     scriptError.init(aMessage, null, null, 0, 0,
                      Components.interfaces.nsIScriptError.warningFlag,
                      "component javascript");
-    getConsoleService().logMessage(scriptError);
+    Services.console.logMessage(scriptError);
 }
 
 /**
@@ -1058,7 +971,7 @@ function ERROR(aMessage) {
     scriptError.init(aMessage, null, null, 0, 0,
                      Components.interfaces.nsIScriptError.errorFlag,
                      "component javascript");
-    getConsoleService().logMessage(scriptError);
+    Services.console.logMessage(scriptError);
 }
 
 /**
@@ -1115,9 +1028,7 @@ function ASSERT(aCondition, aMessage, aCritical) {
 function showError(aMsg) {
     let window = window || null;
     if (window) {
-        let promptService = Components.classes["@mozilla.org/embedcomp/prompt-service;1"]
-                                      .getService(Components.interfaces.nsIPromptService);
-        promptService.alert(window, calGetString("calendar", "genericErrorTitle"), aMsg);
+        Services.prompt.alert(window, calGetString("calendar", "genericErrorTitle"), aMsg);
     }
 }
 
@@ -1271,12 +1182,14 @@ function getProgressAtom(aTask) {
 /**
  * Returns true if we are Sunbird (according to our UUID), false otherwise.
  */
-function isSunbird()
-{
+function isSunbird() {
     if (isSunbird.mIsSunbird === undefined) {
-        var appInfo = Components.classes["@mozilla.org/xre/app-info;1"]
-                                .getService(Components.interfaces.nsIXULAppInfo);
-        isSunbird.mIsSunbird = (appInfo.ID == "{718e30fb-e89b-41dd-9da7-e25a45638b28}");
+        try {
+            isSunbird.mIsSunbird = (Services.appinfo.ID == "{718e30fb-e89b-41dd-9da7-e25a45638b28}");
+        } catch (e) {
+            dump("### Warning: Could not access appinfo, using unreliable check for Lightning\n");
+            isSunbird.mIsSunbird = !("@mozilla.org/lightning/mime-converter;1" in Components.classes);
+        }
     }
     return isSunbird.mIsSunbird;
 }
