@@ -1,4 +1,8 @@
 #!/usr/bin/env python
+# This Source Code Form is subject to the terms of the Mozilla Public
+# License, v. 2.0. If a copy of the MPL was not distributed with this
+# file, You can obtain one at http://mozilla.org/MPL/2.0/.
+
 
 # Warning, this file must be compatible with Python 2.4, for our
 # various tools, such as http://mxr.mozilla.org/ see-also: Bug 601207
@@ -17,15 +21,18 @@ DEFAULTS = {
 
   # URL of the default hg repository to clone for ChatZilla.
   'CHATZILLA_REPO': 'http://hg.mozilla.org/chatzilla/',
-  'CHATZILLA_REV':  'CHATZILLA_0_9_88_2_RELEASE',
+  'CHATZILLA_REV':  'SEA2_15_RELBRANCH',
+
 
   # URL of the default hg repository to clone for DOM Inspector.
   'INSPECTOR_REPO': 'http://hg.mozilla.org/dom-inspector/',
-  'INSPECTOR_REV':  'DOMI_2_0_12',
+  'INSPECTOR_REV':  'DOMI_2_0_13',
+
 
   # URL of the default hg repository to clone for Venkman.
   'VENKMAN_REPO': 'http://hg.mozilla.org/venkman/',
-  'VENKMAN_REV':  'VENKMAN_RELEASE_0_9_89',
+  'VENKMAN_REV':  'SEA2_15_RELBRANCH',
+
 
   # URL of the default hg repository to clone for Mozilla.
   'MOZILLA_REPO': 'http://hg.mozilla.org/releases/mozilla-release/',
@@ -221,10 +228,11 @@ def switch_mozilla_repo():
 
     import ConfigParser, re
     config = ConfigParser.ConfigParser()
-    config.read([os.path.join(mozilla_path, '.hg', 'hgrc')])
+    config_path = os.path.join(mozilla_path, '.hg', 'hgrc')
+    config.read([config_path])
     if not config.has_option('paths', 'default'):
         # Abort, not to get into a possibly inconsistent state.
-        sys.exit("Error: default path in mozilla/.hg/hgrc is undefined!")
+        sys.exit("Error: default path in %s is undefined!" % config_path)
 
     # Compile the Mozilla repository regex.
     moz_old_regex = re.compile(SWITCH_MOZILLA_REPO_REGEXP, re.I)
@@ -403,7 +411,7 @@ o.add_option("--comm-rev", dest="comm_rev",
              help="Revision of comm (Calendar/Mail/Suite) repository to update to. If not present, COMM_REV from the environment will be used. If that doesn't exist the default is: \"" + get_DEFAULT_tag('COMM_REV') + "\"")
 
 o.add_option("-z", "--mozilla-repo", dest="mozilla_repo",
-             default=DEFAULTS['MOZILLA_REPO'],
+             default=None,
              help="URL of Mozilla repository to pull from (default: use hg default in mozilla/.hg/hgrc; or if that file doesn't exist, use \"" + DEFAULTS['MOZILLA_REPO'] + "\".)")
 o.add_option("--skip-mozilla", dest="skip_mozilla",
              action="store_true", default=False,
@@ -515,10 +523,21 @@ def fixup_mozilla_repo_options(options):
 
     See fixup_comm_repo_options().
     """
-    if options.mozilla_repo is None and \
-            not os.path.exists(os.path.join(topsrcdir, 'mozilla')):
-        options.mozilla_repo = DEFAULTS['MOZILLA_REPO']
-    
+    if options.mozilla_repo is None:
+        if not os.path.exists(os.path.join(topsrcdir, 'mozilla')):
+            options.mozilla_repo = DEFAULTS['MOZILLA_REPO']
+        else:
+            # Fallback to using .hgrc as hgtool/share needs the repo
+            import ConfigParser, re
+            config = ConfigParser.ConfigParser()
+            config_path = os.path.join(topsrcdir, 'mozilla', '.hg', 'hgrc')
+            config.read([config_path])
+            if not config.has_option('paths', 'default'):
+                # Abort, not to get into a possibly inconsistent state.
+                sys.exit("Error: default path in %s is undefined!" % config_path)
+
+            options.mozilla_repo = config.get('paths', 'default')
+
     if options.mozilla_rev is None:
         # If we weren't passed an explicit rev, try to find it from the
         # environment. If that doesn't exist or is empty, grab the default.
