@@ -1,40 +1,7 @@
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1/GPL 2.0/LGPL 2.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is mozilla.org code.
- *
- * The Initial Developer of the Original Code is
- * Netscape Communications Corporation.
- * Portions created by the Initial Developer are Copyright (C) 2005
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *   Mark Banner <bugzilla@standard8.demon.co.uk>
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either the GNU General Public License Version 2 or later (the "GPL"), or
- * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
- * in which case the provisions of the GPL or the LGPL are applicable instead
- * of those above. If you wish to allow use of your version of this file only
- * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the MPL, indicate your
- * decision by deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL or the LGPL. If you do not delete
- * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the MPL, the GPL or the LGPL.
- *
- * ***** END LICENSE BLOCK ***** */
+/* This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 #include "nsIAddrDatabase.h"
 #include "nsStringGlue.h"
 #include "nsAbLDIFService.h"
@@ -93,7 +60,7 @@ static unsigned char b642nib[0x80] = {
     0x31, 0x32, 0x33, 0xff, 0xff, 0xff, 0xff, 0xff
 };
 
-NS_IMETHODIMP nsAbLDIFService::ImportLDIFFile(nsIAddrDatabase *aDb, nsIFile *aSrc, bool aStoreLocAsHome, PRUint32 *aProgress)
+NS_IMETHODIMP nsAbLDIFService::ImportLDIFFile(nsIAddrDatabase *aDb, nsIFile *aSrc, bool aStoreLocAsHome, uint32_t *aProgress)
 {
   NS_ENSURE_ARG_POINTER(aSrc);
   NS_ENSURE_ARG_POINTER(aDb);
@@ -102,13 +69,13 @@ NS_IMETHODIMP nsAbLDIFService::ImportLDIFFile(nsIAddrDatabase *aDb, nsIFile *aSr
 
   char buf[1024];
   char* pBuf = &buf[0];
-  PRInt32 startPos = 0;
-  PRUint32 len = 0;
+  int32_t startPos = 0;
+  uint32_t len = 0;
   nsVoidArray listPosArray;   // where each list/group starts in ldif file
   nsVoidArray listSizeArray;  // size of the list/group info
-  PRInt32 savedStartPos = 0;
-  PRInt32 filePos = 0;
-  PRUint32 bytesLeft = 0;
+  int32_t savedStartPos = 0;
+  int32_t filePos = 0;
+  uint64_t bytesLeft = 0;
 
   nsCOMPtr<nsIInputStream> inputStream;
   nsresult rv = NS_NewLocalFileInputStream(getter_AddRefs(inputStream), aSrc);
@@ -138,7 +105,7 @@ NS_IMETHODIMP nsAbLDIFService::ImportLDIFFile(nsIAddrDatabase *aDb, nsIFile *aSr
       }
       filePos += len;
       if (aProgress)
-        *aProgress = (PRUint32)filePos;
+        *aProgress = (uint32_t)filePos;
     }
   }
   //last row
@@ -146,9 +113,9 @@ NS_IMETHODIMP nsAbLDIFService::ImportLDIFFile(nsIAddrDatabase *aDb, nsIFile *aSr
     AddLdifRowToDatabase(aDb, false); 
 
   // mail Lists
-  PRInt32 i, pos;
-  PRUint32 size;
-  PRInt32 listTotal = listPosArray.Count();
+  int32_t i, pos;
+  uint32_t size;
+  int32_t listTotal = listPosArray.Count();
   char *listBuf;
   ClearLdifRecordBuffer();  // make sure the buffer is clean
 
@@ -311,8 +278,8 @@ char* nsAbLDIFService::str_getline(char **next) const
   char    *lineStr;
   char    c;
 
-  if ( *next == nsnull || **next == '\n' || **next == '\0' ) {
-    return( nsnull);
+  if ( *next == nullptr || **next == '\n' || **next == '\0' ) {
+    return( nullptr);
   }
 
   lineStr = *next;
@@ -330,7 +297,7 @@ char* nsAbLDIFService::str_getline(char **next) const
   return( lineStr );
 }
 
-nsresult nsAbLDIFService::GetLdifStringRecord(char* buf, PRInt32 len, PRInt32& stopPos)
+nsresult nsAbLDIFService::GetLdifStringRecord(char* buf, int32_t len, int32_t& stopPos)
 {
   for (; stopPos < len; stopPos++) 
   {
@@ -401,7 +368,7 @@ void nsAbLDIFService::AddLdifRowToDatabase(nsIAddrDatabase *aDatabase,
   char* typeSlot = 0; 
   char* valueSlot = 0; 
   int length = 0;  // the length  of an ldif attribute
-  while ( (line = str_getline(&cursor)) != nsnull)
+  while ( (line = str_getline(&cursor)) != nullptr)
   {
     if ( str_parse_line(line, &typeSlot, &valueSlot, &length) == 0) {
       AddLdifColToDatabase(aDatabase, newRow, typeSlot, valueSlot, bIsList);
@@ -423,8 +390,8 @@ void nsAbLDIFService::AddLdifColToDatabase(nsIAddrDatabase *aDatabase,
                                            nsIMdbRow* newRow, char* typeSlot,
                                            char* valueSlot, bool bIsList)
 {
-  nsCAutoString colType(typeSlot);
-  nsCAutoString column(valueSlot);
+  nsAutoCString colType(typeSlot);
+  nsAutoCString column(valueSlot);
 
   // 4.x exports attributes like "givenname", 
   // mozilla does "givenName" to be compliant with RFC 2798
@@ -537,7 +504,7 @@ void nsAbLDIFService::AddLdifColToDatabase(nsIAddrDatabase *aDatabase,
     // This will remove the label and place the URI as the work URL
     else if (colType.EqualsLiteral("labeleduri"))
     {
-      PRInt32 index = column.FindChar(' ');
+      int32_t index = column.FindChar(' ');
       if (index != -1)
         column.SetLength(index);
 
@@ -655,7 +622,7 @@ void nsAbLDIFService::AddLdifColToDatabase(nsIAddrDatabase *aDatabase,
 
     else if (colType.EqualsLiteral("postofficebox"))
     {
-      nsCAutoString workAddr1, workAddr2;
+      nsAutoCString workAddr1, workAddr2;
       SplitCRLFAddressField(column, workAddr1, workAddr2);
       aDatabase->AddWorkAddress(newRow, workAddr1.get());
       aDatabase->AddWorkAddress2(newRow, workAddr2.get());
@@ -685,7 +652,7 @@ void nsAbLDIFService::AddLdifColToDatabase(nsIAddrDatabase *aDatabase,
 
     else if (colType.EqualsLiteral("streetaddress"))
     {
-      nsCAutoString addr1, addr2;
+      nsAutoCString addr1, addr2;
       SplitCRLFAddressField(column, addr1, addr2);
       if (mStoreLocAsHome)
       {
@@ -789,7 +756,7 @@ static const char *const sLDIFFields[] = {
     "cn",
     "givenName",
     "mail",
-    nsnull
+    nullptr
 };
 #define kMaxLDIFLen        14
 
@@ -811,14 +778,14 @@ NS_IMETHODIMP nsAbLDIFService::IsLDIFFile(nsIFile *pSrc, bool *_retval)
   nsCOMPtr<nsILineInputStream> lineInputStream(do_QueryInterface(fileStream, &rv));
   NS_ENSURE_SUCCESS(rv, rv);
 
-  PRInt32 lineLen = 0;
-  PRInt32 lineCount = 0;
-  PRInt32 ldifFields = 0;  // total number of legal ldif fields.
+  int32_t lineLen = 0;
+  int32_t lineCount = 0;
+  int32_t ldifFields = 0;  // total number of legal ldif fields.
   char field[kMaxLDIFLen];
-  PRInt32 fLen = 0;
+  int32_t fLen = 0;
   const char *pChar;
-  PRInt32 recCount = 0;  // total number of records.
-  PRInt32 i;
+  int32_t recCount = 0;  // total number of records.
+  int32_t i;
   bool gotLDIF = false;
   bool more = true;
   nsCString line;
@@ -837,7 +804,7 @@ NS_IMETHODIMP nsAbLDIFService::IsLDIFFile(nsIFile *pSrc, bool *_retval)
         gotLDIF = false;
       }
                    
-      if (lineLen && (*pChar != ' ') && (*pChar != 9))
+      if (lineLen && (*pChar != ' ') && (*pChar != '\t'))
       {
         fLen = 0;
 
@@ -891,7 +858,7 @@ NS_IMETHODIMP nsAbLDIFService::IsLDIFFile(nsIFile *pSrc, bool *_retval)
 
 void nsAbLDIFService::SplitCRLFAddressField(nsCString &inputAddress, nsCString &outputLine1, nsCString &outputLine2) const
 {
-  PRInt32 crlfPos = inputAddress.Find("\r\n");
+  int32_t crlfPos = inputAddress.Find("\r\n");
   if (crlfPos != -1)
   {
     outputLine1 = Substring(inputAddress, 0, crlfPos);
