@@ -1,42 +1,7 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- * ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1/GPL 2.0/LGPL 2.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is Mozilla Communicator client code, released
- * March 31, 1998.
- *
- * The Initial Developer of the Original Code is
- * Netscape Communications Corporation.
- * Portions created by the Initial Developer are Copyright (C) 1998-1999
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *   Joey Minta <jminta@gmail.com>
- *   Joshua Cranmer <Pidgeot18@gmail.com>
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either of the GNU General Public License Version 2 or later (the "GPL"),
- * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
- * in which case the provisions of the GPL or the LGPL are applicable instead
- * of those above. If you wish to allow use of your version of this file only
- * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the MPL, indicate your
- * decision by deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL or the LGPL. If you do not delete
- * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the MPL, the GPL or the LGPL.
- *
- * ***** END LICENSE BLOCK ***** */
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 /*
  * here's how this dialog works:
@@ -81,10 +46,6 @@ var currentPageId;
 var pendingAccount;
 var pendingPageId;
 
-// services used
-var smtpService;
-var nsPrefBranch;
-
 // This sets an attribute in a xul element so that we can later
 // know what value to substitute in a prefstring.  Different
 // preference types set different attributes.  We get the value
@@ -102,8 +63,8 @@ function updateElementWithKeys(account, element, type) {
       element["serverkey"] = account.incomingServer.key;
       break;
     case "smtp":
-      if (smtpService.defaultServer)
-        element["serverkey"] = smtpService.defaultServer.key;
+      if (MailServices.smtp.defaultServer)
+        element["serverkey"] = MailServices.smtp.defaultServer.key;
       break;
     default:
 //      dump("unknown element type! "+type+"\n");
@@ -150,9 +111,6 @@ function onLoad() {
   accountArray = new Object();
   gGenericAttributeTypes = new Object();
 
-  smtpService =
-    Components.classes["@mozilla.org/messengercompose/smtp;1"].getService(Components.interfaces.nsISmtpService);
-
   gAccountTree.load();
 
   setTimeout(selectServer, 0, selectedServer, selectPage);
@@ -162,7 +120,7 @@ function onUnload() {
   gAccountTree.unload();
 }
 
-function selectServer(server, selectPage)
+function selectServer(server, selectPageId)
 {
   let childrenNode = document.getElementById("account-tree-children");
 
@@ -171,7 +129,7 @@ function selectServer(server, selectPage)
 
   // Find the tree-node for the account we want to select
   if (server) {
-    for (var i = 0; i < childrenNode.childNodes.length; i++) {
+    for (let i = 0; i < childrenNode.childNodes.length; i++) {
       let account = childrenNode.childNodes[i]._account;
       if (account && server == account.incomingServer) {
         accountNode = childrenNode.childNodes[i];
@@ -180,19 +138,25 @@ function selectServer(server, selectPage)
     }
   }
 
-  var pageToSelect = accountNode;
-  if (selectPage) {
-    // Find the page that also corresponds to this server
-    var pages = accountNode.getElementsByAttribute("PageTag", selectPage);
-    pageToSelect = pages[0];
+  let pageToSelect = accountNode;
+
+  if (selectPageId) {
+    // Find the page that also corresponds to this server.
+    // It either is the accountNode itself...
+    let pageId = accountNode.getAttribute("PageTag");
+    if (pageId != selectPageId) {
+      // ... or one of its children.
+      let pages = accountNode.getElementsByAttribute("PageTag", selectPageId);
+      pageToSelect = pages[0];
+    }
   }
 
-  var accountTree = document.getElementById("accounttree");
-  var index = accountTree.contentView.getIndexOfItem(pageToSelect);
+  let accountTree = document.getElementById("accounttree");
+  let index = accountTree.contentView.getIndexOfItem(pageToSelect);
   accountTree.view.selection.select(index);
   accountTree.treeBoxObject.ensureRowIsVisible(index);
 
-  var lastItem = accountNode.lastChild.lastChild;
+  let lastItem = accountNode.lastChild.lastChild;
   if (lastItem.localName == "treeitem")
     index = accountTree.contentView.getIndexOfItem(lastItem);
 
@@ -201,11 +165,10 @@ function selectServer(server, selectPage)
 
 function replaceWithDefaultSmtpServer(deletedSmtpServerKey)
 {
-  //First we replace the smtpserverkey in every identity
-  const Ci = Components.interfaces;
-  var am = Components.classes["@mozilla.org/messenger/account-manager;1"]
-                     .getService(Ci.nsIMsgAccountManager);
-  for each (var identity in fixIterator(am.allIdentities, Ci.nsIMsgIdentity)) {
+  // First we replace the smtpserverkey in every identity.
+  let am = MailServices.accounts;
+  for each (let identity in fixIterator(am.allIdentities,
+                                        Components.interfaces.nsIMsgIdentity)) {
     if (identity.smtpServerKey == deletedSmtpServerKey)
       identity.smtpServerKey = "";
   }
@@ -220,7 +183,7 @@ function replaceWithDefaultSmtpServer(deletedSmtpServerKey)
 
   for (var accountid in accountArray) {
     var account = accountArray[accountid]._account;
-    if(account && account.defaultIdentity) {
+    if (account && account.defaultIdentity) {
       var accountValues = accountArray[accountid];
       var smtpServerKey = getAccountValue(account, accountValues, "identity",
                                           "smtpServerKey", null, false);
@@ -230,14 +193,23 @@ function replaceWithDefaultSmtpServer(deletedSmtpServerKey)
   }
 }
 
-function onAccept() {
-  // Check if user/host have been modified correctly.
-  if (!checkUserServerChanges(true))
-    return false;
+/**
+ * Called when OK is clicked on the dialog.
+ *
+ * @param aDoChecks  If true, execute checks on data, otherwise hope they
+ *                   were already done elsewhere and proceed directly to saving
+ *                   the data.
+ */
+function onAccept(aDoChecks) {
+  if (aDoChecks) {
+    // Check if user/host have been modified correctly.
+    if (!checkUserServerChanges(true))
+      return false;
 
-  if (gSmtpHostNameIsIllegal) {
-    gSmtpHostNameIsIllegal = false;
-    return false;
+    if (gSmtpHostNameIsIllegal) {
+      gSmtpHostNameIsIllegal = false;
+      return false;
+    }
   }
 
   if (!onSave())
@@ -255,17 +227,115 @@ function onAccept() {
   return true;
 }
 
-// Check if the user and/or host names have been changed and
-// if so check if the new names already exists for an account
-// or are empty.
-// Also check if the Local Directory path was changed.
+/**
+ * See if the given path to a directory is usable on the current OS.
+ *
+ * aLocalPath  the nsIFile of a directory to check.
+ */
+function checkDirectoryIsValid(aLocalPath) {
+  // Any directory selected in the file picker already exists.
+  // Any directory specified in prefs.js will be created at start if it does
+  // not exist yet.
+  // If at the time of entering Account Manager the directory does not exist,
+  // it must be invalid in the current OS or not creatable due to permissions.
+  // Even then, the backend sometimes tries to create a new one
+  // under the current profile.
+  if (!aLocalPath.exists() || !aLocalPath.isDirectory())
+    return false;
+
+  if (Services.appinfo.OS == "WINNT") {
+    // Do not allow some special filenames on Windows.
+    // Taken from mozilla/widget/windows/nsDataObj.cpp::MangleTextToValidFilename()
+    let dirLeafName = aLocalPath.leafName;
+    const kForbiddenNames = [
+      "COM1", "COM2", "COM3", "COM4", "COM5", "COM6", "COM7", "COM8", "COM9",
+      "LPT1", "LPT2", "LPT3", "LPT4", "LPT5", "LPT6", "LPT7", "LPT8", "LPT9",
+      "CON", "PRN", "AUX", "NUL", "CLOCK$" ];
+    if (kForbiddenNames.indexOf(dirLeafName) != -1)
+      return false;
+  }
+
+  // The directory must be readable and writable to work as a mail store.
+  if (!(aLocalPath.isReadable() && aLocalPath.isWritable()))
+    return false;
+
+  return true;
+}
+
+/**
+ * Check if the specified directory does meet all the requirements
+ * for safe mail storage.
+ *
+ * aLocalPath  the nsIFile of a directory to check.
+ */
+function checkDirectoryIsUsable(aLocalPath) {
+  const kAlertTitle = document.getElementById("bundle_prefs")
+                              .getString("prefPanel-server");
+  let invalidPath = false;
+  try{
+    aLocalPath.normalize();
+  } catch (e) { invalidPath = true; }
+
+  if (invalidPath || !checkDirectoryIsValid(aLocalPath)) {
+    let alertString = document.getElementById("bundle_prefs")
+                              .getString("localDirectoryInvalid");
+    Services.prompt.alert(window, kAlertTitle, alertString);
+    return false;
+  }
+
+  // Check that no other account has this same or dependent local directory.
+  let allServers = MailServices.accounts.allServers;
+
+  for each (let server in fixIterator(allServers,
+                                      Components.interfaces.nsIMsgIncomingServer))
+  {
+    if (server.key == currentAccount.incomingServer.key)
+      continue;
+
+    let serverPath = server.localPath;
+    try {
+      serverPath.normalize();
+      let alertStringID = null;
+      if (serverPath.equals(aLocalPath))
+        alertStringID = "directoryAlreadyUsedByOtherAccount";
+      else if (serverPath.contains(aLocalPath, true))
+        alertStringID = "directoryParentUsedByOtherAccount";
+      else if (aLocalPath.contains(serverPath, true))
+        alertStringID = "directoryChildUsedByOtherAccount";
+
+      if (alertStringID) {
+        let alertString = document.getElementById("bundle_prefs")
+                                  .getFormattedString(alertStringID,
+                                                      [server.prettyName]);
+
+        Services.prompt.alert(window, kAlertTitle, alertString);
+        return false;
+      }
+    } catch (e) {
+      // The other account's path is seriously broken, so we can't compare it.
+      Components.utils.reportError("The Local Directory path of the account " +
+        server.prettyName + " seems invalid.");
+    }
+  }
+
+  return true;
+}
+
+/**
+ * Check if the user and/or host names have been changed and if so check
+ * if the new names already exists for an account or are empty.
+ * Also check if the Local Directory path was changed.
+ *
+ * @param showAlert  show and alert if a problem with the host / user name is found
+ */
 function checkUserServerChanges(showAlert) {
   const prefBundle = document.getElementById("bundle_prefs");
   const alertTitle = prefBundle.getString("prefPanel-server");
   var alertText = null;
-  if (smtpService.defaultServer) {
+  if (MailServices.smtp.defaultServer) {
     try {
-      var smtpHostName = top.frames["contentFrame"].document.getElementById("smtp.hostname");
+      var smtpHostName = top.frames["contentFrame"]
+                            .document.getElementById("smtp.hostname");
       if (smtpHostName && hostnameIsIllegal(smtpHostName.value)) {
         alertText = prefBundle.getString("enterValidHostname");
         Services.prompt.alert(window, alertTitle, alertText);
@@ -280,7 +350,7 @@ function checkUserServerChanges(showAlert) {
     return true;
 
   var pageElements = getPageFormElements();
-  if (pageElements == null)
+  if (!pageElements)
     return true;
 
   // Get the new username, hostname and type from the page
@@ -320,11 +390,13 @@ function checkUserServerChanges(showAlert) {
   }
   alertText = null;
   // If something is changed then check if the new user/host already exists.
-  if ( (oldUser != newUser) || (oldHost != newHost) ) {
+  if ((oldUser != newUser) || (oldHost != newHost)) {
     if ((checkUser && (newUser == "")) || (newHost == "")) {
         alertText = prefBundle.getString("serverNameEmpty");
     } else {
-      if (MailServices.accounts.findRealServer(newUser, newHost, newType, 0))
+      let sameServer = MailServices.accounts
+                                   .findRealServer(newUser, newHost, newType, 0)
+      if (sameServer && (sameServer != currentAccount.incomingServer))
         alertText = prefBundle.getString("modifiedAccountExists");
     }
     if (alertText) {
@@ -334,30 +406,41 @@ function checkUserServerChanges(showAlert) {
       if (checkUser)
         setFormElementValue(pageElements[uIndx], oldUser);
       setFormElementValue(pageElements[hIndx], oldHost);
-      return false;
+      // If no message is shown to the user, silently revert the values
+      // and consider the check a success.
+      return !showAlert;
     }
 
     // If username is changed remind users to change Your Name and Email Address.
-    // If server name is changed and has defined filters then remind users to edit rules.
+    // If server name is changed and has defined filters then remind users
+    // to edit rules.
     if (showAlert) {
-      var filterList;
+      let filterList;
       if (currentAccount && checkUser) {
         filterList = currentAccount.incomingServer.getEditableFilterList(null);
       }
-      var userChangeText, serverChangeText;
-      if ( (oldHost != newHost) && (filterList != undefined) && filterList.filterCount )
-        serverChangeText = prefBundle.getString("serverNameChanged");
+      let changeText = "";
+      if ((oldHost != newHost) &&
+          (filterList != undefined) && filterList.filterCount)
+        changeText = prefBundle.getString("serverNameChanged");
+      // In the event that oldHost == newHost or oldUser == newUser,
+      // the \n\n will be trimmed off before the message is shown.
       if (oldUser != newUser)
-        userChangeText = prefBundle.getString("userNameChanged");
+        changeText = changeText + "\n\n" + prefBundle.getString("userNameChanged");
 
-      if ( (serverChangeText != undefined) && (userChangeText != undefined) )
-        serverChangeText = serverChangeText + "\n\n" + userChangeText;
-      else
-        if (userChangeText != undefined)
-          serverChangeText = userChangeText;
+      if (changeText != "")
+        Services.prompt.alert(window, alertTitle, changeText.trim());
+    }
+  }
 
-      if (serverChangeText != undefined)
-        Services.prompt.alert(window, alertTitle, serverChangeText);
+  // Check the new value of the server.localPath field for validity.
+  for (let i = 0; i < pageElements.length; i++) {
+    if (pageElements[i].id) {
+      if (pageElements[i].id == "server.localPath") {
+        if (!checkDirectoryIsUsable(getFormElementValue(pageElements[i])))
+          return false;
+        break;
+      }
     }
   }
 
@@ -419,10 +502,7 @@ function onAddAccount() {
 
 function AddMailAccount()
 {
-  let msgWindow = Components.classes["@mozilla.org/messenger/services/session;1"]
-                            .getService(Components.interfaces.nsIMsgMailSession)
-                            .topmostMsgWindow;
-  NewMailAccount(msgWindow);
+  NewMailAccount(MailServices.mailSession.topmostMsgWindow);
 }
 
 function AddIMAccount()
@@ -494,21 +574,44 @@ function onRemoveAccount(event) {
   if (!Services.prompt.confirm(window, confirmTitle, confirmRemoveAccount))
     return;
 
+  let serverList = [];
+  let accountTreeNode = document.getElementById("account-tree-children");
+  // build the list of servers in the account tree (order is important)
+  for (let i = 0; i < accountTreeNode.childNodes.length; i++) {
+    if ("_account" in accountTreeNode.childNodes[i]) {
+      let curServer = accountTreeNode.childNodes[i]._account.incomingServer;
+      if (serverList.indexOf(curServer) == -1)
+        serverList.push(curServer);
+    }
+  }
+
+  // get position of the current server in the server list
+  let serverIndex = serverList.indexOf(server);
+
+  // After the current server is deleted, choose the next server/account,
+  // or the previous one if the last one was deleted.
+  if (serverIndex == serverList.length - 1)
+    serverIndex--;
+  else
+    serverIndex++;
+
   try {
     let serverId = server.serverURI;
     MailServices.accounts.removeAccount(currentAccount);
 
-    currentAccount = currentPageId = null;
     // clear cached data out of the account array
+    currentAccount = currentPageId = null;
     if (serverId in accountArray) {
       delete accountArray[serverId];
     }
-    selectServer(null, null);
+
+    if ((serverIndex >= 0) && (serverIndex < serverList.length))
+      selectServer(serverList[serverIndex], null);
   }
   catch (ex) {
-    dump("failure to remove account: " + ex + "\n");
+    Components.utils.reportError("Failure to remove account: " + ex);
     let alertText = bundle.getString("failedRemoveAccount");
-    Services.prompt.alert(window, null, alertText);;
+    Services.prompt.alert(window, null, alertText);
   }
 
   // Either the default account was deleted so there is a new one
@@ -546,7 +649,7 @@ function saveAccount(accountValues, account)
       else if (type == "nntp")
         dest = server.QueryInterface(Components.interfaces.nsINntpIncomingServer);
       else if (type == "smtp")
-        dest = smtpService.defaultServer;
+        dest = MailServices.smtp.defaultServer;
 
       } catch (ex) {
         // don't do anything, just means we don't support that
@@ -621,117 +724,102 @@ function saveAccount(accountValues, account)
   return true;
 }
 
+/**
+ * Set enabled/disabled state for account actions buttons.
+ * Called by all apps, but if the buttons do not exist, exits early.
+ */
 function updateButtons(tree, account) {
-  var canCreate = true;
-  var canDelete = true;
-  var canSetDefault = true;
-
-  if (account) {
-    var server = account.incomingServer;
-    var type = server.type;
-
-    var am = Components.classes["@mozilla.org/messenger/account-manager;1"]
-                       .getService(Components.interfaces.nsIMsgAccountManager);
-    if (account == am.defaultAccount || !server.canBeDefaultServer ||
-        account.identities.Count() < 1)
-      canSetDefault = false;
-
-    var protocolinfo = Components.classes["@mozilla.org/messenger/protocol/info;1?type=" + type].getService(Components.interfaces.nsIMsgProtocolInfo);
-    canDelete = protocolinfo.canDelete;
-    if (!canDelete) {
-      canDelete = server.canDelete;
-    }
-  }
-  else {
-    // HACK
-    // if account is null, we have either selected a SMTP server, or there is a problem
-    // either way, we don't want the user to be able to delete it.
-
-    canSetDefault = false;
-    canDelete = false;
-  }
-
-  if (tree.view.selection.count < 1)
-    canSetDefault = canDelete = false;
-
-  // check for disabled preferences on the account buttons.  
-  //  Not currently handled by WSM or the main loop yet since these buttons aren't
-  //  under the IFRAME
-  var addAccountButton = document.getElementById("addAccountButton");
-  var removeButton = document.getElementById("removeButton");
-  var setDefaultButton = document.getElementById("setDefaultButton");
+  let addAccountButton = document.getElementById("addAccountButton");
+  let removeButton = document.getElementById("removeButton");
+  let setDefaultButton = document.getElementById("setDefaultButton");
 
   if (!addAccountButton && !removeButton && !setDefaultButton)
-    return; // tb isn't useing these anymore
+    return; // Thunderbird isn't using these.
 
-  var prefBranch = Components.classes["@mozilla.org/preferences-service;1"]
-                             .getService(Components.interfaces.nsIPrefBranch);
-  if (prefBranch.prefIsLocked(addAccountButton.getAttribute("prefstring")))
-    canCreate = false;
-  if (prefBranch.prefIsLocked(setDefaultButton.getAttribute("prefstring")))
-    canSetDefault = false;
-  if (prefBranch.prefIsLocked(removeButton.getAttribute("prefstring")))
-    canDelete = false;
-
-  setEnabled(addAccountButton, canCreate);
-  setEnabled(setDefaultButton, canSetDefault);
-  setEnabled(removeButton, canDelete);
+  updateItems(tree, account, addAccountButton, setDefaultButton, removeButton);
+  updateBlockedItems([addAccountButton, setDefaultButton, removeButton], false);
 }
 
 /**
  * Set enabled/disabled state for the actions in the Account Actions menu.
+ * Called only by Thunderbird.
  */
-function initAcountActionsButton(menupopup) {
-  let account = getCurrentAccount();
-  if (account) {
-    let server = account.incomingServer;
-
-    let am = Components.classes["@mozilla.org/messenger/account-manager;1"]
-                      .getService(Components.interfaces.nsIMsgAccountManager);
-    if (account == am.defaultAccount || !server.canBeDefaultServer ||
-        account.identities.Count() < 1)
-      document.getElementById("accountActionsDropdownSetDefault")
-              .setAttribute("disabled", true);
-    else
-      document.getElementById("accountActionsDropdownSetDefault")
-              .removeAttribute("disabled");
-
-    let protocolInfo = Components.classes["@mozilla.org/messenger/protocol/info;1?type=" + server.type]
-                                .getService(Components.interfaces.nsIMsgProtocolInfo);
-    if (!protocolInfo.canDelete)
-      document.getElementById("accountActionsDropdownRemove")
-              .setAttribute("disabled", true);
-    else
-      document.getElementById("accountActionsDropdownRemove")
-              .removeAttribute("disabled");
-  }
-  else { // SMTP server
-    document.getElementById("accountActionsDropdownSetDefault")
-            .setAttribute("disabled", true);
-    document.getElementById("accountActionsDropdownRemove")
-            .setAttribute("disabled", true);
-  }
-
-  let prefBranch = Components.classes["@mozilla.org/preferences-service;1"]
-                             .getService(Components.interfaces.nsIPrefBranch);
-  if (!prefBranch.getBoolPref("mail.chat.enabled"))
+function initAccountActionsButtons(menupopup) {
+  if (!Services.prefs.getBoolPref("mail.chat.enabled"))
     document.getElementById("accountActionsAddIMAccount").hidden = true;
 
-  let children = menupopup.childNodes;
-  for (let i = 0; i < children.length; i++) {
-    let prefstring = children[i].getAttribute("prefstring");
+  updateItems(
+    document.getElementById("accounttree"),
+    getCurrentAccount(),
+    document.getElementById("accountActionsAddMailAccount"),
+    document.getElementById("accountActionsDropdownSetDefault"),
+    document.getElementById("accountActionsDropdownRemove"));
+
+  updateBlockedItems(menupopup.childNodes, true);
+}
+
+/**
+ * Determine enabled/disabled state for the passed in elements
+ * representing account actions.
+ */
+function updateItems(tree, account, addAccountItem, setDefaultItem, removeItem) {
+  // Start with items disabled and then find out what can be enabled.
+  let canSetDefault = false;
+  let canDelete = false;
+
+  if (account && (tree.view.selection.count >= 1)) {
+    // Only try to check properties if there was anything selected in the tree
+    // and it belongs to an account.
+    // Otherwise we have either selected a SMTP server, or there is some
+    // problem. Either way, we don't want the user to act on it.
+    let server = account.incomingServer;
+    let type = server.type;
+
+    if (account != MailServices.accounts.defaultAccount &&
+        server.canBeDefaultServer && account.identities.Count() > 0)
+      canSetDefault = true;
+
+    if (Components.classes["@mozilla.org/messenger/protocol/info;1?type=" + type]
+                  .getService(Components.interfaces.nsIMsgProtocolInfo).canDelete)
+      canDelete = true;
+    else
+      canDelete = server.canDelete;
+  }
+
+  setEnabled(addAccountItem, true);
+  setEnabled(setDefaultItem, canSetDefault);
+  setEnabled(removeItem, canDelete);
+}
+
+/**
+ * Disable buttons/menu items if their control preference is locked.
+ * SeaMonkey: Not currently handled by WSM or the main loop yet
+ * since these buttons aren't under the IFRAME.
+ *
+ * @param aItems  the elements to be checked
+ * @param aMustBeTrue  if true then the pref must be boolean and set to true
+ *                     to trigger the disabling (TB requires this, SM not)
+ */
+function updateBlockedItems(aItems, aMustBeTrue) {
+  for each (let [, item] in Iterator(aItems)) {
+    let prefstring = item.getAttribute("prefstring");
     if (!prefstring)
       continue;
 
-    if (prefBranch.prefIsLocked(prefstring) && prefBranch.getBoolPref(prefstring))
-      children[i].setAttribute("disabled", true);
+    if (Services.prefs.prefIsLocked(prefstring) &&
+        (!aMustBeTrue || Services.prefs.getBoolPref(prefstring)))
+      item.setAttribute("disabled", true);
   }
 }
 
-
+/**
+ * Set enabled/disabled state for the control.
+ */
 function setEnabled(control, enabled)
 {
-  if (!control) return;
+  if (!control)
+    return;
+
   if (enabled)
     control.removeAttribute("disabled");
   else
@@ -748,23 +836,40 @@ function onAccountTreeSelect(pageId, account)
   let changeView = pageId && account;
   if (!changeView) {
     if (tree.view.selection.count < 1)
-      return null;
+      return false;
 
     let node = tree.contentView.getItemAtIndex(tree.currentIndex);
-    account = node._account;
+    account = ("_account" in node) ? node._account : null;
+
     pageId = node.getAttribute("PageTag")
   }
 
   if (pageId == currentPageId && account == currentAccount)
-    return;
+    return true;
 
-  // check if user/host names have been changed
-  checkUserServerChanges(false);
+  if (document.getElementById("contentFrame").contentDocument.getElementById("server.localPath")) {
+    // Check if user/host names have been changed or the Local Directory is invalid.
+    if (!checkUserServerChanges(false)) {
+      changeView = true;
+      account = currentAccount;
+      pageId = currentPageId;
+    }
 
-  if (gSmtpHostNameIsIllegal) {
-    gSmtpHostNameIsIllegal = false;
-    selectServer(currentAccount.incomingServer, currentPageId);
-    return;
+    if (gSmtpHostNameIsIllegal) {
+      gSmtpHostNameIsIllegal = false;
+      selectServer(currentAccount.incomingServer, currentPageId);
+      return true;
+    }
+
+    if (gRestartNeeded)
+      onAccept(false);
+  }
+
+  if (currentPageId) {
+    // Change focus to the account tree first so that any 'onchange' handlers
+    // on elements in the current page have a chance to run before the page
+    // is saved and replaced by the new one.
+    tree.focus();
   }
 
   // save the previous page
@@ -791,6 +896,8 @@ function onAccountTreeSelect(pageId, account)
 
   if (changeAccount)
     updateButtons(tree, account);
+
+  return true;
 }
 
 // page has loaded
@@ -819,19 +926,15 @@ function onPanelLoaded(pageId) {
 
 function loadPage(pageId)
 {
-  var chromePackageName;
-  try 
-  {
+  let chromePackageName;
+  try {
     // we could compare against "main","server","copies","offline","addressing",
     // "smtp" and "advanced" first to save the work, but don't,
     // as some of these might be turned into extensions (for thunderbird)
-    var am = Components.classes["@mozilla.org/messenger/account-manager;1"]
-                       .getService(Components.interfaces.nsIMsgAccountManager);
-    var package = pageId.split("am-")[1].split(".xul")[0];
-    chromePackageName = am.getChromePackageName(package);
+    let packageName = pageId.split("am-")[1].split(".xul")[0];
+    chromePackageName = MailServices.accounts.getChromePackageName(packageName);
   }
-  catch (ex) 
-  {
+  catch (ex) {
     chromePackageName = "messenger";
   }
   const LOAD_FLAGS_NONE = Components.interfaces.nsIWebNavigation.LOAD_FLAGS_NONE;
@@ -849,15 +952,15 @@ function savePage(account)
     top.frames["contentFrame"].onSave();
 
   var accountValues = getValueArrayFor(account);
-  if (!accountValues) 
+  if (!accountValues)
     return;
 
   var pageElements = getPageFormElements();
-  if (!pageElements) 
+  if (!pageElements)
     return;
 
   // store the value in the account
-  for (var i=0; i<pageElements.length; i++) {
+  for (var i = 0; i < pageElements.length; i++) {
     if (pageElements[i].id) {
       var vals = pageElements[i].id.split(".");
       if (vals.length >= 2) {
@@ -903,7 +1006,7 @@ function getAccountValue(account, accountValues, type, slot, preftype, isGeneric
     else if (type == "nntp")
       source = server.QueryInterface(Components.interfaces.nsINntpIncomingServer);
     else if (type == "smtp")
-      source = smtpService.defaultServer;
+      source = MailServices.smtp.defaultServer;
     } catch (ex) {
     }
 
@@ -955,18 +1058,18 @@ function restorePage(pageId, account)
     return;
 
   var accountValues = getValueArrayFor(account);
-  if (!accountValues) 
+  if (!accountValues)
     return;
 
   if ("onPreInit" in top.frames["contentFrame"])
     top.frames["contentFrame"].onPreInit(account, accountValues);
 
   var pageElements = getPageFormElements();
-  if (!pageElements) 
+  if (!pageElements)
     return;
 
   // restore the value from the account
-  for (var i=0; i<pageElements.length; i++) {
+  for (var i = 0; i < pageElements.length; i++) {
     if (pageElements[i].id) {
       var vals = pageElements[i].id.split(".");
       if (vals.length >= 2) {
@@ -990,12 +1093,12 @@ function restorePage(pageId, account)
             element["serverkey"] = account.incomingServer.key;
             break;
           case "smtp":
-            if (smtpService.defaultServer)
-              element["serverkey"] = smtpService.defaultServer.key;
+            if (MailServices.smtp.defaultServer)
+              element["serverkey"] = MailServices.smtp.defaultServer.key;
             break;
         }
         var isLocked = getAccountValueIsLocked(pageElements[i]);
-        setEnabled(pageElements[i],!isLocked);
+        setEnabled(pageElements[i], !isLocked);
       }
     }
   }
@@ -1123,9 +1226,11 @@ function getCurrentAccount()
 
 // get the array of form elements for the given page
 function getPageFormElements() {
-  if("getElementsByAttribute" in top.frames["contentFrame"].document)
+  if ("getElementsByAttribute" in top.frames["contentFrame"].document)
     return top.frames["contentFrame"].document
               .getElementsByAttribute("wsm_persist", "true");
+
+  return null;
 }
 
 // get the value array for the given account
@@ -1226,8 +1331,9 @@ var gAccountTree = {
         panelsToKeep.push(panels[4]); // and addresssing
       }
 
-      // Everyone except news and RSS has a junk panel
+      // Everyone except News, RSS and IM has a junk panel
       // XXX: unextensible!
+      // The existence of server.spamSettings can't currently be used for this.
       if (server.type != "nntp" && server.type != "rss" && server.type != "im")
         panelsToKeep.push(panels[5]);
 
