@@ -1,40 +1,7 @@
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1/GPL 2.0/LGPL 2.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is the Mozilla Penelope project.
- *
- * The Initial Developer of the Original Code is
- * QUALCOMM Incorporated.
- * Portions created by QUALCOMM Incorporated are
- * Copyright (C) 2007 QUALCOMM Incorporated. All Rights Reserved.
- *
- * Contributor(s):
- *   Jeff Beckley <beckley@qualcomm.com> original author
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either the GNU General Public License Version 2 or later (the "GPL"), or
- * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
- * in which case the provisions of the GPL or the LGPL are applicable instead
- * of those above. If you wish to allow use of your version of this file only
- * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the MPL, indicate your
- * decision by deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL or the LGPL. If you do not delete
- * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the MPL, the GPL or the LGPL.
- *
- * ***** END LICENSE BLOCK ***** */
+/* This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 /*
   Eudora filters
@@ -52,6 +19,7 @@
 #include "nsIMsgFilterList.h"
 #include "nsIMsgAccountManager.h"
 #include "nsIStringBundle.h"
+#include "mozilla/Services.h"
 
 #include "nsEudoraFilters.h"
 #include "nsEudoraStringBundle.h"
@@ -95,20 +63,20 @@ NS_IMETHODIMP nsEudoraFilters::AutoLocate(PRUnichar **aDescription, nsIFile **aL
   NS_ENSURE_ARG_POINTER(aLocation);
   NS_ENSURE_ARG_POINTER(_retval);
 
-  *aDescription = nsnull;
+  *aDescription = nullptr;
   *_retval = false;
 
   nsresult rv;
   m_pLocation =  do_CreateInstance (NS_LOCAL_FILE_CONTRACTID, &rv);
   NS_ENSURE_SUCCESS(rv, rv);
 
-  *aDescription = nsEudoraStringBundle::GetStringByID( EUDORAIMPORT_NAME);
+  *aDescription = nsEudoraStringBundle::GetStringByID(EUDORAIMPORT_NAME);
 
 #if defined(XP_WIN) || defined(XP_OS2)
-  *_retval = nsEudoraWin32::FindFiltersFile( getter_AddRefs(m_pLocation) );
+  *_retval = nsEudoraWin32::FindFiltersFile(getter_AddRefs(m_pLocation));
 #endif
 #ifdef XP_MACOSX
-  *_retval = nsEudoraMac::FindFiltersFile( getter_AddRefs(m_pLocation) );
+  *_retval = nsEudoraMac::FindFiltersFile(getter_AddRefs(m_pLocation));
 #endif
 
   NS_IF_ADDREF(*aLocation = m_pLocation);
@@ -119,7 +87,7 @@ NS_IMETHODIMP nsEudoraFilters::SetLocation(nsIFile *aLocation)
 {
   m_pLocation = aLocation;
 
-  return( NS_OK);
+  return NS_OK;
 }
 
 NS_IMETHODIMP nsEudoraFilters::Import(PRUnichar **aError, bool *_retval)
@@ -129,7 +97,7 @@ NS_IMETHODIMP nsEudoraFilters::Import(PRUnichar **aError, bool *_retval)
   nsresult rv;
 
   *_retval = false;
-  *aError = nsnull;
+  *aError = nullptr;
 
   // Get the settings file if it doesn't exist
   if (!m_pLocation)
@@ -138,18 +106,18 @@ NS_IMETHODIMP nsEudoraFilters::Import(PRUnichar **aError, bool *_retval)
     NS_ENSURE_SUCCESS(rv, rv);
 #if defined(XP_WIN) || defined(XP_OS2)
     if (!nsEudoraWin32::FindFiltersFile(getter_AddRefs(m_pLocation)))
-      m_pLocation = nsnull;
+      m_pLocation = nullptr;
 #endif
 #ifdef XP_MACOSX
     if (!nsEudoraMac::FindFiltersFile(getter_AddRefs(m_pLocation)))
-      m_pLocation = nsnull;
+      m_pLocation = nullptr;
 #endif
   }
 
   if (!m_pLocation)
   {
-    IMPORT_LOG0( "*** Error, unable to locate filters file for import.\n");
-    return( NS_ERROR_FAILURE);
+    IMPORT_LOG0("*** Error, unable to locate filters file for import.\n");
+    return NS_ERROR_FAILURE;
   }
 
   // Now perform actual importing task
@@ -157,11 +125,11 @@ NS_IMETHODIMP nsEudoraFilters::Import(PRUnichar **aError, bool *_retval)
   *aError = ToNewUnicode(m_errorLog);
 
   if (*_retval)
-    IMPORT_LOG0( "Successful import of eudora filters\n");
+    IMPORT_LOG0("Successful import of eudora filters\n");
   else
-    IMPORT_LOG0( "*** Error, Unsuccessful import of eudora filters\n");
+    IMPORT_LOG0("*** Error, Unsuccessful import of eudora filters\n");
 
-  return( NS_OK);
+  return NS_OK;
 }
 
 bool nsEudoraFilters::RealImport()
@@ -171,7 +139,7 @@ bool nsEudoraFilters::RealImport()
   rv = Init();
   if (NS_FAILED(rv))
   {
-    IMPORT_LOG0( "*** Error initializing filter import process\n");
+    IMPORT_LOG0("*** Error initializing filter import process\n");
     return false;
   }
 
@@ -180,14 +148,14 @@ bool nsEudoraFilters::RealImport()
 
   if (NS_FAILED(rv))
   {
-    IMPORT_LOG0( "*** Error opening filters file for reading\n");
+    IMPORT_LOG0("*** Error opening filters file for reading\n");
     return false;
   }
 
   rv = LoadServers();
   if (NS_FAILED(rv))
   {
-    IMPORT_LOG0( "*** Error loading servers with filters\n");
+    IMPORT_LOG0("*** Error loading servers with filters\n");
     return false;
   }
 
@@ -196,8 +164,8 @@ bool nsEudoraFilters::RealImport()
 
   nsCString     line;
   bool          more = true;
-  nsCAutoString header;
-  nsCAutoString verb;
+  nsAutoCString header;
+  nsAutoCString verb;
   nsAutoString  name;
 
   // Windows Eudora filters files have a version header as a first line - just skip it
@@ -285,7 +253,7 @@ bool nsEudoraFilters::RealImport()
         // Win Eudora's  priority values are 0 (highest) to 4 (lowest)
         // Mac Eudora's  priority values are 1 (highest) to 5 (lowest)
         // Thunderbird's priority values are 6 (highest) to 2 (lowest)
-        PRInt32 TBPriority = 6 - atoi(pLine + 9);
+        int32_t TBPriority = 6 - atoi(pLine + 9);
 #ifdef XP_MACOSX
         TBPriority++;
 #endif
@@ -293,7 +261,7 @@ bool nsEudoraFilters::RealImport()
       }
       else if (!strncmp(pLine, "label ", 6))
       {
-        nsCAutoString tagName("$label");
+        nsAutoCString tagName("$label");
         tagName += pLine + 6;
         rv = AddStringAction(nsMsgFilterAction::AddTag, tagName.get());
       }
@@ -303,7 +271,7 @@ bool nsEudoraFilters::RealImport()
       else if (!strncmp(pLine, "status ", 7))
       {
         // Win Eudora's read status is 1, whereas Mac Eudora's read status is 2
-        PRUint32 status = atoi(pLine + 7);
+        uint32_t status = atoi(pLine + 7);
 #ifdef XP_MACOSX
         status--;
 #endif
@@ -313,7 +281,7 @@ bool nsEudoraFilters::RealImport()
       else if (!strncmp(pLine, "serverOpt ", 10))
       {
         // Win and Mac Eudora have the two bits swapped in the file
-        PRUint32 bits = atoi(pLine + 10);
+        uint32_t bits = atoi(pLine + 10);
 #if defined(XP_WIN) || defined(XP_OS2)
         bool bFetch  = (bits & 1);
         bool bDelete = (bits & 2);
@@ -357,7 +325,7 @@ bool nsEudoraFilters::RealImport()
 
   if (more)
   {
-    IMPORT_LOG0( "*** Error reading the filters, didn't reach the end\n");
+    IMPORT_LOG0("*** Error reading the filters, didn't reach the end\n");
     return false;
   }
 
@@ -389,20 +357,19 @@ nsresult nsEudoraFilters::Init()
 
   // Get the name of the folder where one-off imported mail is placed
   nsAutoString folderName(NS_LITERAL_STRING("Eudora Import"));
-  nsCOMPtr<nsIStringBundleService> bundleService(do_GetService(
-                                     NS_STRINGBUNDLE_CONTRACTID, &rv));
+  nsCOMPtr<nsIStringBundleService> bundleService = 
+    mozilla::services::GetStringBundleService();
+  NS_ENSURE_TRUE(bundleService, NS_ERROR_UNEXPECTED);
+
+  nsCOMPtr<nsIStringBundle> bundle;
+  rv = bundleService->CreateBundle("chrome://messenger/locale/importMsgs.properties",
+                                   getter_AddRefs(bundle));
   if (NS_SUCCEEDED(rv))
   {
-    nsCOMPtr<nsIStringBundle> bundle;
-    rv = bundleService->CreateBundle("chrome://messenger/locale/importMsgs.properties",
-                                     getter_AddRefs(bundle));
-    if (NS_SUCCEEDED(rv))
-    {
-      nsAutoString Eudora(NS_LITERAL_STRING("Eudora"));
-      const PRUnichar *moduleName[] = { Eudora.get() };
-      rv = bundle->FormatStringFromName(NS_LITERAL_STRING("ImportModuleFolderName").get(),
-                                        moduleName, 1, getter_Copies(folderName));
-    }
+    nsAutoString Eudora(NS_LITERAL_STRING("Eudora"));
+    const PRUnichar *moduleName[] = { Eudora.get() };
+    rv = bundle->FormatStringFromName(NS_LITERAL_STRING("ImportModuleFolderName").get(),
+                                      moduleName, 1, getter_Copies(folderName));
   }
   localRootFolder->GetChildNamed(folderName, getter_AddRefs(m_pMailboxesRoot));
   if (!m_pMailboxesRoot)
@@ -436,10 +403,10 @@ nsresult nsEudoraFilters::LoadServers()
   rv = accountMgr->GetAllServers(getter_AddRefs(allServers));
   NS_ENSURE_SUCCESS(rv, rv);
 
-  PRUint32 numServers;
+  uint32_t numServers;
   rv = allServers->Count(&numServers);
   NS_ENSURE_SUCCESS(rv, rv);
-  for (PRUint32 serverIndex = 0; serverIndex < numServers; serverIndex++)
+  for (uint32_t serverIndex = 0; serverIndex < numServers; serverIndex++)
   {
     nsCOMPtr<nsIMsgIncomingServer> server = do_QueryElementAt(allServers, serverIndex, &rv);
     if (server && NS_SUCCEEDED(rv))
@@ -448,7 +415,7 @@ nsresult nsEudoraFilters::LoadServers()
       rv = server->GetCanHaveFilters(&canHaveFilters);
       if (NS_SUCCEEDED(rv) && canHaveFilters)
       {
-        nsCAutoString serverType;
+        nsAutoCString serverType;
         rv = server->GetType(serverType);
         if (NS_SUCCEEDED(rv) && !serverType.IsEmpty())
         {
@@ -459,7 +426,7 @@ nsresult nsEudoraFilters::LoadServers()
             // Pre-fetch filters now so that if there's any problem reading up the
             // filter file we know about it in advance and can stop importing
             nsCOMPtr<nsIMsgFilterList> filterList;
-            rv = server->GetFilterList(nsnull, getter_AddRefs(filterList));
+            rv = server->GetFilterList(nullptr, getter_AddRefs(filterList));
             NS_ENSURE_SUCCESS(rv, rv);
 
             m_pServerArray->AppendElement(server);
@@ -476,16 +443,16 @@ nsresult nsEudoraFilters::SaveFilters()
 {
   nsresult rv;
 
-  PRUint32 numServers;
+  uint32_t numServers;
   rv = m_pServerArray->Count(&numServers);
   NS_ENSURE_SUCCESS(rv, rv);
-  for (PRUint32 serverIndex = 0; serverIndex < numServers; serverIndex++)
+  for (uint32_t serverIndex = 0; serverIndex < numServers; serverIndex++)
   {
     nsCOMPtr<nsIMsgIncomingServer> server = do_QueryElementAt(m_pServerArray, serverIndex, &rv);
     NS_ENSURE_SUCCESS(rv, rv);
 
     nsCOMPtr <nsIMsgFilterList> filterList;
-    rv = server->GetFilterList(nsnull, getter_AddRefs(filterList));
+    rv = server->GetFilterList(nullptr, getter_AddRefs(filterList));
     NS_ENSURE_SUCCESS(rv, rv);
 
     rv = filterList->SaveToDefaultFile();
@@ -504,16 +471,16 @@ nsresult nsEudoraFilters::CreateNewFilter(const char* pName)
 
   nsAutoString unicodeName;
   NS_CopyNativeToUnicode(nsCString(pName), unicodeName);
-  PRUint32 numServers;
+  uint32_t numServers;
   rv = m_pServerArray->Count(&numServers);
   NS_ENSURE_SUCCESS(rv, rv);
-  for (PRUint32 serverIndex = 0; serverIndex < numServers; serverIndex++)
+  for (uint32_t serverIndex = 0; serverIndex < numServers; serverIndex++)
   {
     nsCOMPtr<nsIMsgIncomingServer> server = do_QueryElementAt(m_pServerArray, serverIndex, &rv);
     NS_ENSURE_SUCCESS(rv, rv);
 
     nsCOMPtr <nsIMsgFilterList> filterList;
-    rv = server->GetFilterList(nsnull, getter_AddRefs(filterList));
+    rv = server->GetFilterList(nullptr, getter_AddRefs(filterList));
     NS_ENSURE_SUCCESS(rv, rv);
 
     nsCOMPtr<nsIMsgFilter> newFilter;
@@ -523,7 +490,7 @@ nsresult nsEudoraFilters::CreateNewFilter(const char* pName)
     rv = newFilter->SetEnabled(false);
     NS_ENSURE_SUCCESS(rv, rv);
 
-    PRUint32 count;
+    uint32_t count;
     rv = filterList->GetFilterCount(&count);
     NS_ENSURE_SUCCESS(rv, rv);
 
@@ -569,10 +536,10 @@ nsresult nsEudoraFilters::EnableFilter(bool enable)
 {
   nsresult rv;
 
-  PRUint32 numFilters;
+  uint32_t numFilters;
   rv = m_pFilterArray->Count(&numFilters);
   NS_ENSURE_SUCCESS(rv, rv);
-  for (PRUint32 filterIndex = 0; filterIndex < numFilters; filterIndex++)
+  for (uint32_t filterIndex = 0; filterIndex < numFilters; filterIndex++)
   {
     nsCOMPtr<nsIMsgFilter> filter = do_QueryElementAt(m_pFilterArray, filterIndex, &rv);
     NS_ENSURE_SUCCESS(rv, rv);
@@ -596,21 +563,21 @@ static const char* gStandardHeaders[] =
 {
 // Eudora string        nsMsgSearchAttribValue
 // -------------        ----------------------
-    "Subject:",              // Subject
-    "From:",                 // Sender
-    LDAQ"Body"RDAQ,          // Body
-    "Date:",                 // Date
-    "X-Priority:",           // Priority
-    "",                      // MsgStatus
-    "To:",                   // To
-    "Cc:",                   // CC
-    LDAQ"Any Recipient"RDAQ, // ToOrCC
+    "Subject:",                // Subject
+    "From:",                   // Sender
+    LDAQ "Body" RDAQ,          // Body
+    "Date:",                   // Date
+    "X-Priority:",             // Priority
+    "",                        // MsgStatus
+    "To:",                     // To
+    "Cc:",                     // CC
+    LDAQ "Any Recipient" RDAQ, // ToOrCC
     NULL
 };
 
-static PRInt32 FindHeader(const char* pHeader)
+static int32_t FindHeader(const char* pHeader)
 {
-  for (PRInt32 i = 0; gStandardHeaders[i]; i++)
+  for (int32_t i = 0; gStandardHeaders[i]; i++)
   {
     if (*gStandardHeaders[i] && !PL_strcasecmp(pHeader, gStandardHeaders[i]))
       return i;
@@ -644,9 +611,9 @@ static const char* gOperators[] =
     NULL
 };
 
-static PRInt32 FindOperator(const char* pOperator)
+static int32_t FindOperator(const char* pOperator)
 {
-  for (PRInt32 i = 0; gOperators[i]; i++)
+  for (int32_t i = 0; gOperators[i]; i++)
   {
     if (*gOperators[i] && !strcmp(pOperator, gOperators[i]))
       return i;
@@ -657,20 +624,20 @@ static PRInt32 FindOperator(const char* pOperator)
 
 #define MAILNEWS_CUSTOM_HEADERS "mailnews.customHeaders"
 
-static PRInt32 AddCustomHeader(const char* pHeader)
+static int32_t AddCustomHeader(const char* pHeader)
 {
   nsresult rv;
-  PRInt32 index = -1;
+  int32_t index = -1;
   nsCOMPtr<nsIPrefBranch> pref(do_GetService(NS_PREFSERVICE_CONTRACTID, &rv));
   NS_ENSURE_SUCCESS(rv, index);
 
-  nsCAutoString headers;
+  nsAutoCString headers;
   pref->GetCharPref(MAILNEWS_CUSTOM_HEADERS, getter_Copies(headers));
   index = 0;
   if (!headers.IsEmpty())
   {
     char *headersString = ToNewCString(headers);
-    nsCAutoString hdrStr;
+    nsAutoCString hdrStr;
     hdrStr.Adopt(headersString);
     hdrStr.StripWhitespace();  //remove whitespace before parsing
 
@@ -697,7 +664,7 @@ nsresult nsEudoraFilters::AddTerm(const char* pHeader, const char* pVerb, const
 
   nsMsgSearchAttribValue attrib = FindHeader(pHeader);
   nsMsgSearchOpValue     op = FindOperator(pVerb);
-  nsCAutoString          arbitraryHeader;
+  nsAutoCString          arbitraryHeader;
   nsAutoString           unicodeHeader, unicodeVerb, unicodeValue;
   nsAutoString           filterTitle;
 
@@ -764,20 +731,20 @@ nsresult nsEudoraFilters::AddTerm(const char* pHeader, const char* pVerb, const
 
     // Arbitrary headers for filters don't like the colon at the end
     arbitraryHeader = pHeader;
-    PRInt32 index = arbitraryHeader.FindChar(':');
+    int32_t index = arbitraryHeader.FindChar(':');
     if (index >= 0)
       arbitraryHeader.SetLength(index);
 
-    PRInt32 headerIndex = AddCustomHeader(arbitraryHeader.get());
+    int32_t headerIndex = AddCustomHeader(arbitraryHeader.get());
     NS_ENSURE_TRUE(headerIndex >= 0, NS_ERROR_FAILURE);
 
     attrib = nsMsgSearchAttrib::OtherHeader + 1 + headerIndex;
   }
 
-  PRUint32 numFilters;
+  uint32_t numFilters;
   rv = m_pFilterArray->Count(&numFilters);
   NS_ENSURE_SUCCESS(rv, rv);
-  for (PRUint32 filterIndex = 0; filterIndex < numFilters; filterIndex++)
+  for (uint32_t filterIndex = 0; filterIndex < numFilters; filterIndex++)
   {
     nsCOMPtr<nsIMsgFilter> filter = do_QueryElementAt(m_pFilterArray, filterIndex, &rv);
     NS_ENSURE_SUCCESS(rv, rv);
@@ -793,7 +760,7 @@ nsresult nsEudoraFilters::AddTerm(const char* pHeader, const char* pVerb, const
       if (NS_SUCCEEDED(rv) && term)
       {
         term->SetBooleanAnd(true);
-        term = nsnull;
+        term = nullptr;
       }
     }
 
@@ -818,15 +785,15 @@ nsresult nsEudoraFilters::AddTerm(const char* pHeader, const char* pVerb, const
   return NS_OK;
 }
 
-nsresult nsEudoraFilters::AddAction(nsMsgRuleActionType actionType, PRInt32 junkScore /*= 0*/, nsMsgLabelValue label/*= 0*/,
-                                    nsMsgPriorityValue priority/*= 0*/, const char* strValue/*= nsnull*/, const char* targetFolderUri/*= nsnull*/)
+nsresult nsEudoraFilters::AddAction(nsMsgRuleActionType actionType, int32_t junkScore /*= 0*/, nsMsgLabelValue label/*= 0*/,
+                                    nsMsgPriorityValue priority/*= 0*/, const char* strValue/*= nullptr*/, const char* targetFolderUri/*= nullptr*/)
 {
   nsresult rv;
 
-  PRUint32 numFilters;
+  uint32_t numFilters;
   rv = m_pFilterArray->Count(&numFilters);
   NS_ENSURE_SUCCESS(rv, rv);
-  for (PRUint32 filterIndex = 0; filterIndex < numFilters; filterIndex++)
+  for (uint32_t filterIndex = 0; filterIndex < numFilters; filterIndex++)
   {
     nsCOMPtr<nsIMsgFilter> filter = do_QueryElementAt(m_pFilterArray, filterIndex, &rv);
     NS_ENSURE_SUCCESS(rv, rv);
@@ -842,7 +809,7 @@ nsresult nsEudoraFilters::AddAction(nsMsgRuleActionType actionType, PRInt32 junk
     {
       case nsMsgFilterAction::MoveToFolder:
       case nsMsgFilterAction::CopyToFolder:
-        rv = action->SetTargetFolderUri(nsCAutoString(targetFolderUri));
+        rv = action->SetTargetFolderUri(nsAutoCString(targetFolderUri));
         break;
 
       case nsMsgFilterAction::ChangePriority:
@@ -856,7 +823,7 @@ nsresult nsEudoraFilters::AddAction(nsMsgRuleActionType actionType, PRInt32 junk
       case nsMsgFilterAction::AddTag:
       case nsMsgFilterAction::Reply:
       case nsMsgFilterAction::Forward:
-        rv = action->SetStrValue(nsCAutoString(strValue));
+        rv = action->SetStrValue(nsAutoCString(strValue));
         break;
 
       case nsMsgFilterAction::MarkRead:
@@ -895,7 +862,7 @@ nsresult nsEudoraFilters::AddMailboxAction(const char* pMailboxPath, bool isTran
 #if defined(XP_WIN) || defined(XP_OS2)
   nsCString filePath;
   m_pLocation->GetNativePath(filePath);
-  PRInt32 index = filePath.RFindChar('\\');
+  int32_t index = filePath.RFindChar('\\');
   if (index >= 0)
     filePath.SetLength(index);
   if (!nsEudoraWin32::GetMailboxNameHierarchy(filePath, pMailboxPath,
@@ -909,13 +876,13 @@ nsresult nsEudoraFilters::AddMailboxAction(const char* pMailboxPath, bool isTran
   nsCOMPtr<nsIMsgFolder> folder;
   rv = GetMailboxFolder(nameHierarchy.get(), getter_AddRefs(folder));
 
-  nsCAutoString folderURI;
+  nsAutoCString folderURI;
   if (NS_SUCCEEDED(rv))
     rv = folder->GetURI(folderURI);
   if (NS_FAILED(rv))
     return NS_ERROR_INVALID_ARG;
 
-  rv = AddAction(isTransfer? (nsMsgRuleActionType)nsMsgFilterAction::MoveToFolder : (nsMsgRuleActionType)nsMsgFilterAction::CopyToFolder, 0, 0, 0, nsnull, folderURI.get());
+  rv = AddAction(isTransfer? (nsMsgRuleActionType)nsMsgFilterAction::MoveToFolder : (nsMsgRuleActionType)nsMsgFilterAction::CopyToFolder, 0, 0, 0, nullptr, folderURI.get());
 
   if (NS_SUCCEEDED(rv) && isTransfer)
     m_hasTransfer = true;
@@ -931,10 +898,10 @@ nsresult nsEudoraFilters::GetMailboxFolder(const char* pNameHierarchy, nsIMsgFol
 
   // We've already grabbed the pointer on incoming, so now ensure
   // *ppFolder is null on outgoing if there is an error
-  *ppFolder = nsnull;
+  *ppFolder = nullptr;
   
-  nsCAutoString name(pNameHierarchy + 1);
-  PRInt32 sepIndex = name.FindChar(*pNameHierarchy);
+  nsAutoCString name(pNameHierarchy + 1);
+  int32_t sepIndex = name.FindChar(*pNameHierarchy);
   if (sepIndex >= 0)
     name.SetLength(sepIndex);
 
