@@ -1,40 +1,7 @@
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1/GPL 2.0/LGPL 2.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is mozilla.org code.
- *
- * The Initial Developer of the Original Code is
- * Netscape Communications Corporation.
- * Portions created by the Initial Developer are Copyright (C) 1998
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *   Pierre Phaneuf <pp@ludusdesign.com>
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either of the GNU General Public License Version 2 or later (the "GPL"),
- * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
- * in which case the provisions of the GPL or the LGPL are applicable instead
- * of those above. If you wish to allow use of your version of this file only
- * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the MPL, indicate your
- * decision by deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL or the LGPL. If you do not delete
- * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the MPL, the GPL or the LGPL.
- *
- * ***** END LICENSE BLOCK ***** */
+/* This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 #include "prprf.h"
 #include "plstr.h"
@@ -47,7 +14,7 @@
 #include "nsIImportABDescriptor.h"
 #include "nsIImportFieldMap.h"
 #include "nsStringGlue.h"
-#include "nsILocalFile.h"
+#include "nsIFile.h"
 #include "nsIAddrDatabase.h"
 #include "nsIAbManager.h"
 #include "nsIAbLDIFService.h"
@@ -63,7 +30,7 @@
 #include "nsISupportsArray.h"
 #include "nsCOMArray.h"
 
-static void ImportAddressThread( void *stuff);
+static void ImportAddressThread(void *stuff);
 
 class AddressThreadData;
 
@@ -81,7 +48,7 @@ public:
 
   NS_IMETHOD SetData(const char *dataId, nsISupports *pData);
 
-  NS_IMETHOD GetStatus( const char *statusKind, PRInt32 *_retval);
+  NS_IMETHOD GetStatus(const char *statusKind, int32_t *_retval);
 
   NS_IMETHOD WantsProgress(bool *_retval);
 
@@ -89,17 +56,17 @@ public:
 
   NS_IMETHOD ContinueImport(bool *_retval);
 
-  NS_IMETHOD GetProgress(PRInt32 *_retval);
+  NS_IMETHOD GetProgress(int32_t *_retval);
 
   NS_IMETHOD CancelImport(void);
 
 private:
-  void  GetDefaultLocation( void);
-  void  GetDefaultBooks( void);
-  void  GetDefaultFieldMap( void);
+  void  GetDefaultLocation(void);
+  void  GetDefaultBooks(void);
+  void  GetDefaultFieldMap(void);
 
 public:
-  static void  SetLogs( nsString& success, nsString& error, nsISupportsString *pSuccess, nsISupportsString *pError);
+  static void  SetLogs(nsString& success, nsString& error, nsISupportsString *pSuccess, nsISupportsString *pError);
   static void ReportError(const PRUnichar *pName, nsString *pStream,
                           nsIStringBundle *aBundle);
 
@@ -116,7 +83,7 @@ private:
   bool              m_userVerify;
   nsISupportsString *    m_pSuccessLog;
   nsISupportsString *    m_pErrorLog;
-  PRUint32          m_totalSize;
+  uint32_t          m_totalSize;
   bool              m_doImport;
   AddressThreadData *      m_pThreadData;
   char *            m_pDestinationUri;
@@ -129,8 +96,8 @@ public:
   bool              threadAlive;
   bool              abort;
   bool              fatalError;
-  PRUint32          currentTotal;
-  PRUint32          currentSize;
+  uint32_t          currentTotal;
+  uint32_t          currentSize;
   nsISupportsArray *      books;
   nsCOMArray<nsIAddrDatabase>* dBs;
   nsCOMPtr<nsIAbLDIFService> ldifService;
@@ -148,36 +115,36 @@ public:
 
 nsresult NS_NewGenericAddressBooks(nsIImportGeneric** aImportGeneric)
 {
-    NS_PRECONDITION(aImportGeneric != nsnull, "null ptr");
+    NS_PRECONDITION(aImportGeneric != nullptr, "null ptr");
     if (! aImportGeneric)
         return NS_ERROR_NULL_POINTER;
 
   nsImportGenericAddressBooks *pGen = new nsImportGenericAddressBooks();
 
-  if (pGen == nsnull)
+  if (pGen == nullptr)
     return NS_ERROR_OUT_OF_MEMORY;
 
-  NS_ADDREF( pGen);
-  nsresult rv = pGen->QueryInterface( NS_GET_IID(nsIImportGeneric), (void **)aImportGeneric);
-  NS_RELEASE( pGen);
+  NS_ADDREF(pGen);
+  nsresult rv = pGen->QueryInterface(NS_GET_IID(nsIImportGeneric), (void **)aImportGeneric);
+  NS_RELEASE(pGen);
 
-    return( rv);
+    return rv;
 }
 
 nsImportGenericAddressBooks::nsImportGenericAddressBooks()
 {
-  m_pInterface = nsnull;
-  m_pBooks = nsnull;
-  m_pSuccessLog = nsnull;
-  m_pErrorLog = nsnull;
+  m_pInterface = nullptr;
+  m_pBooks = nullptr;
+  m_pSuccessLog = nullptr;
+  m_pErrorLog = nullptr;
   m_totalSize = 0;
   m_doImport = false;
-  m_pThreadData = nsnull;
-  m_pDestinationUri = nsnull;
-  m_pFieldMap = nsnull;
+  m_pThreadData = nullptr;
+  m_pDestinationUri = nullptr;
+  m_pFieldMap = nullptr;
 
   m_autoFind = false;
-  m_description = nsnull;
+  m_description = nullptr;
   m_gotLocation = false;
   m_found = false;
   m_userVerify = false;
@@ -189,16 +156,16 @@ nsImportGenericAddressBooks::nsImportGenericAddressBooks()
 nsImportGenericAddressBooks::~nsImportGenericAddressBooks()
 {
   if (m_pDestinationUri)
-    NS_Free( m_pDestinationUri);
+    NS_Free(m_pDestinationUri);
 
   if (m_description)
-    NS_Free( m_description);
+    NS_Free(m_description);
 
-  NS_IF_RELEASE( m_pFieldMap);
-  NS_IF_RELEASE( m_pInterface);
-  NS_IF_RELEASE( m_pBooks);
-  NS_IF_RELEASE( m_pSuccessLog);
-  NS_IF_RELEASE( m_pErrorLog);
+  NS_IF_RELEASE(m_pFieldMap);
+  NS_IF_RELEASE(m_pInterface);
+  NS_IF_RELEASE(m_pBooks);
+  NS_IF_RELEASE(m_pSuccessLog);
+  NS_IF_RELEASE(m_pErrorLog);
 }
 
 
@@ -208,42 +175,42 @@ NS_IMPL_THREADSAFE_ISUPPORTS1(nsImportGenericAddressBooks, nsIImportGeneric)
 
 NS_IMETHODIMP nsImportGenericAddressBooks::GetData(const char *dataId, nsISupports **_retval)
 {
-  NS_PRECONDITION(_retval != nsnull, "null ptr");
+  NS_PRECONDITION(_retval != nullptr, "null ptr");
   if (!_retval)
     return NS_ERROR_NULL_POINTER;
 
   nsresult rv;
-  *_retval = nsnull;
-  if (!PL_strcasecmp( dataId, "addressInterface")) {
+  *_retval = nullptr;
+  if (!PL_strcasecmp(dataId, "addressInterface")) {
     *_retval = m_pInterface;
-    NS_IF_ADDREF( m_pInterface);
+    NS_IF_ADDREF(m_pInterface);
   }
 
-  if (!PL_strcasecmp( dataId, "addressLocation")) {
+  if (!PL_strcasecmp(dataId, "addressLocation")) {
     if (!m_pLocation)
       GetDefaultLocation();
     NS_IF_ADDREF(*_retval = m_pLocation);
   }
 
-  if (!PL_strcasecmp( dataId, "addressBooks")) {
+  if (!PL_strcasecmp(dataId, "addressBooks")) {
     if (!m_pLocation)
       GetDefaultLocation();
     if (!m_pBooks)
       GetDefaultBooks();
     *_retval = m_pBooks;
-    NS_IF_ADDREF( m_pBooks);
+    NS_IF_ADDREF(m_pBooks);
   }
 
-  if (!PL_strcasecmp( dataId, "addressDestination")) {
+  if (!PL_strcasecmp(dataId, "addressDestination")) {
     if (m_pDestinationUri) {
             nsCOMPtr<nsISupportsCString> abString = do_CreateInstance(NS_SUPPORTS_CSTRING_CONTRACTID, &rv);
             NS_ENSURE_SUCCESS(rv, rv);
             abString->SetData(nsDependentCString(m_pDestinationUri));
-            NS_IF_ADDREF( *_retval = abString);
+            NS_IF_ADDREF(*_retval = abString);
     }
   }
 
-  if (!PL_strcasecmp( dataId, "fieldMap")) {
+  if (!PL_strcasecmp(dataId, "fieldMap")) {
     if (m_pFieldMap) {
       *_retval = m_pFieldMap;
       m_pFieldMap->AddRef();
@@ -251,7 +218,7 @@ NS_IMETHODIMP nsImportGenericAddressBooks::GetData(const char *dataId, nsISuppor
     else {
       if (m_pInterface && m_pLocation) {
         bool needsIt = false;
-        m_pInterface->GetNeedsFieldMap( m_pLocation, &needsIt);
+        m_pInterface->GetNeedsFieldMap(m_pLocation, &needsIt);
         if (needsIt) {
           GetDefaultFieldMap();
           if (m_pFieldMap) {
@@ -263,57 +230,57 @@ NS_IMETHODIMP nsImportGenericAddressBooks::GetData(const char *dataId, nsISuppor
     }
   }
 
-  if (!PL_strncasecmp( dataId, "sampleData-", 11)) {
+  if (!PL_strncasecmp(dataId, "sampleData-", 11)) {
     // extra the record number
     const char *pNum = dataId + 11;
-    PRInt32  rNum = 0;
+    int32_t  rNum = 0;
     while (*pNum) {
       rNum *= 10;
       rNum += (*pNum - '0');
       pNum++;
     }
-    IMPORT_LOG1( "Requesting sample data #: %ld\n", (long)rNum);
+    IMPORT_LOG1("Requesting sample data #: %ld\n", (long)rNum);
     if (m_pInterface) {
-      nsCOMPtr<nsISupportsString>  data = do_CreateInstance( NS_SUPPORTS_STRING_CONTRACTID, &rv);
-      if (NS_FAILED( rv))
-        return( rv);
-      PRUnichar *  pData = nsnull;
+      nsCOMPtr<nsISupportsString>  data = do_CreateInstance(NS_SUPPORTS_STRING_CONTRACTID, &rv);
+      if (NS_FAILED(rv))
+        return rv;
+      PRUnichar *  pData = nullptr;
       bool      found = false;
-      rv = m_pInterface->GetSampleData( rNum, &found, &pData);
-      if (NS_FAILED( rv))
-        return( rv);
+      rv = m_pInterface->GetSampleData(rNum, &found, &pData);
+      if (NS_FAILED(rv))
+        return rv;
       if (found) {
         data->SetData(nsDependentString(pData));
         *_retval = data;
-        NS_ADDREF( *_retval);
+        NS_ADDREF(*_retval);
       }
-      NS_Free( pData);
+      NS_Free(pData);
     }
   }
 
-  return( NS_OK);
+  return NS_OK;
 }
 
 
-NS_IMETHODIMP nsImportGenericAddressBooks::SetData( const char *dataId, nsISupports *item)
+NS_IMETHODIMP nsImportGenericAddressBooks::SetData(const char *dataId, nsISupports *item)
 {
-  NS_PRECONDITION(dataId != nsnull, "null ptr");
-    if (!dataId)
-        return NS_ERROR_NULL_POINTER;
+  NS_PRECONDITION(dataId != nullptr, "null ptr");
+  if (!dataId)
+    return NS_ERROR_NULL_POINTER;
 
-  if (!PL_strcasecmp( dataId, "addressInterface")) {
-    NS_IF_RELEASE( m_pInterface);
+  if (!PL_strcasecmp(dataId, "addressInterface")) {
+    NS_IF_RELEASE(m_pInterface);
     if (item)
-      item->QueryInterface( NS_GET_IID(nsIImportAddressBooks), (void **) &m_pInterface);
+      item->QueryInterface(NS_GET_IID(nsIImportAddressBooks), (void **) &m_pInterface);
   }
-  if (!PL_strcasecmp( dataId, "addressBooks")) {
-    NS_IF_RELEASE( m_pBooks);
+  if (!PL_strcasecmp(dataId, "addressBooks")) {
+    NS_IF_RELEASE(m_pBooks);
     if (item)
-      item->QueryInterface( NS_GET_IID(nsISupportsArray), (void **) &m_pBooks);
+      item->QueryInterface(NS_GET_IID(nsISupportsArray), (void **) &m_pBooks);
   }
 
-  if (!PL_strcasecmp( dataId, "addressLocation")) {
-    m_pLocation = nsnull;
+  if (!PL_strcasecmp(dataId, "addressLocation")) {
+    m_pLocation = nullptr;
 
     if (item) {
       nsresult rv;
@@ -323,74 +290,74 @@ NS_IMETHODIMP nsImportGenericAddressBooks::SetData( const char *dataId, nsISuppo
 
     if (m_pInterface)
       m_pInterface->SetSampleLocation(m_pLocation);
-    }
+  }
 
-  if (!PL_strcasecmp( dataId, "addressDestination")) {
+  if (!PL_strcasecmp(dataId, "addressDestination")) {
     if (item) {
       nsCOMPtr<nsISupportsCString> abString;
-      item->QueryInterface( NS_GET_IID(nsISupportsCString), getter_AddRefs( abString));
+      item->QueryInterface(NS_GET_IID(nsISupportsCString), getter_AddRefs(abString));
       if (abString) {
         if (m_pDestinationUri)
-          NS_Free( m_pDestinationUri);
-        m_pDestinationUri = nsnull;
-                nsCAutoString tempUri;
+          NS_Free(m_pDestinationUri);
+        m_pDestinationUri = nullptr;
+                nsAutoCString tempUri;
                 abString->GetData(tempUri);
                 m_pDestinationUri = ToNewCString(tempUri);
       }
     }
   }
 
-  if (!PL_strcasecmp( dataId, "fieldMap")) {
-    NS_IF_RELEASE( m_pFieldMap);
+  if (!PL_strcasecmp(dataId, "fieldMap")) {
+    NS_IF_RELEASE(m_pFieldMap);
     if (item)
-      item->QueryInterface( NS_GET_IID(nsIImportFieldMap), (void **) &m_pFieldMap);
+      item->QueryInterface(NS_GET_IID(nsIImportFieldMap), (void **) &m_pFieldMap);
   }
 
-  return( NS_OK);
+  return NS_OK;
 }
 
-NS_IMETHODIMP nsImportGenericAddressBooks::GetStatus( const char *statusKind, PRInt32 *_retval)
+NS_IMETHODIMP nsImportGenericAddressBooks::GetStatus(const char *statusKind, int32_t *_retval)
 {
-  NS_PRECONDITION(statusKind != nsnull, "null ptr");
-  NS_PRECONDITION(_retval != nsnull, "null ptr");
+  NS_PRECONDITION(statusKind != nullptr, "null ptr");
+  NS_PRECONDITION(_retval != nullptr, "null ptr");
   if (!statusKind || !_retval)
-    return( NS_ERROR_NULL_POINTER);
+    return NS_ERROR_NULL_POINTER;
 
   *_retval = 0;
 
-  if (!PL_strcasecmp( statusKind, "isInstalled")) {
+  if (!PL_strcasecmp(statusKind, "isInstalled")) {
     GetDefaultLocation();
-    *_retval = (PRInt32) m_found;
+    *_retval = (int32_t) m_found;
   }
 
-  if (!PL_strcasecmp( statusKind, "canUserSetLocation")) {
+  if (!PL_strcasecmp(statusKind, "canUserSetLocation")) {
     GetDefaultLocation();
-    *_retval = (PRInt32) m_userVerify;
+    *_retval = (int32_t) m_userVerify;
   }
 
-  if (!PL_strcasecmp( statusKind, "autoFind")) {
+  if (!PL_strcasecmp(statusKind, "autoFind")) {
     GetDefaultLocation();
-    *_retval = (PRInt32) m_autoFind;
+    *_retval = (int32_t) m_autoFind;
   }
 
-  if (!PL_strcasecmp( statusKind, "supportsMultiple")) {
+  if (!PL_strcasecmp(statusKind, "supportsMultiple")) {
     bool      multi = false;
     if (m_pInterface)
-      m_pInterface->GetSupportsMultiple( &multi);
-    *_retval = (PRInt32) multi;
+      m_pInterface->GetSupportsMultiple(&multi);
+    *_retval = (int32_t) multi;
   }
 
-  if (!PL_strcasecmp( statusKind, "needsFieldMap")) {
+  if (!PL_strcasecmp(statusKind, "needsFieldMap")) {
     bool      needs = false;
     if (m_pInterface && m_pLocation)
-      m_pInterface->GetNeedsFieldMap( m_pLocation, &needs);
-    *_retval = (PRInt32) needs;
+      m_pInterface->GetNeedsFieldMap(m_pLocation, &needs);
+    *_retval = (int32_t) needs;
   }
 
-  return( NS_OK);
+  return NS_OK;
 }
 
-void nsImportGenericAddressBooks::GetDefaultLocation( void)
+void nsImportGenericAddressBooks::GetDefaultLocation(void)
 {
   if (!m_pInterface)
     return;
@@ -399,9 +366,9 @@ void nsImportGenericAddressBooks::GetDefaultLocation( void)
     return;
 
   if (m_description)
-    NS_Free( m_description);
-  m_description = nsnull;
-  m_pInterface->GetAutoFind( &m_description, &m_autoFind);
+    NS_Free(m_description);
+  m_description = nullptr;
+  m_pInterface->GetAutoFind(&m_description, &m_autoFind);
   m_gotLocation = true;
   if (m_autoFind) {
     m_found = true;
@@ -410,12 +377,12 @@ void nsImportGenericAddressBooks::GetDefaultLocation( void)
   }
 
   nsCOMPtr <nsIFile> pLoc;
-  m_pInterface->GetDefaultLocation( getter_AddRefs(pLoc), &m_found, &m_userVerify);
+  m_pInterface->GetDefaultLocation(getter_AddRefs(pLoc), &m_found, &m_userVerify);
   if (!m_pLocation)
     m_pLocation = pLoc;
 }
 
-void nsImportGenericAddressBooks::GetDefaultBooks( void)
+void nsImportGenericAddressBooks::GetDefaultBooks(void)
 {
   if (!m_pInterface || m_pBooks)
     return;
@@ -423,61 +390,61 @@ void nsImportGenericAddressBooks::GetDefaultBooks( void)
   if (!m_pLocation && !m_autoFind)
     return;
 
-  nsresult rv = m_pInterface->FindAddressBooks( m_pLocation, &m_pBooks);
-  if (NS_FAILED( rv)) {
-    IMPORT_LOG0( "*** Error: FindAddressBooks failed\n");
+  nsresult rv = m_pInterface->FindAddressBooks(m_pLocation, &m_pBooks);
+  if (NS_FAILED(rv)) {
+    IMPORT_LOG0("*** Error: FindAddressBooks failed\n");
   }
 }
 
-void nsImportGenericAddressBooks::GetDefaultFieldMap( void)
+void nsImportGenericAddressBooks::GetDefaultFieldMap(void)
 {
   if (!m_pInterface || !m_pLocation)
     return;
 
-  NS_IF_RELEASE( m_pFieldMap);
+  NS_IF_RELEASE(m_pFieldMap);
 
   nsresult  rv;
   nsCOMPtr<nsIImportService> impSvc(do_GetService(NS_IMPORTSERVICE_CONTRACTID, &rv));
   if (NS_FAILED(rv)) {
-    IMPORT_LOG0( "*** Unable to get nsIImportService.\n");
+    IMPORT_LOG0("*** Unable to get nsIImportService.\n");
     return;
   }
 
-  rv = impSvc->CreateNewFieldMap( &m_pFieldMap);
-  if (NS_FAILED( rv))
+  rv = impSvc->CreateNewFieldMap(&m_pFieldMap);
+  if (NS_FAILED(rv))
     return;
 
-  PRInt32  sz = 0;
-  rv = m_pFieldMap->GetNumMozFields( &sz);
-  if (NS_SUCCEEDED( rv))
-    rv = m_pFieldMap->DefaultFieldMap( sz);
-    if (NS_SUCCEEDED( rv))
+  int32_t  sz = 0;
+  rv = m_pFieldMap->GetNumMozFields(&sz);
+  if (NS_SUCCEEDED(rv))
+    rv = m_pFieldMap->DefaultFieldMap(sz);
+    if (NS_SUCCEEDED(rv))
       rv = m_pInterface->InitFieldMap(m_pFieldMap);
-  if (NS_FAILED( rv)) {
-    IMPORT_LOG0( "*** Error: Unable to initialize field map\n");
-    NS_IF_RELEASE( m_pFieldMap);
+  if (NS_FAILED(rv)) {
+    IMPORT_LOG0("*** Error: Unable to initialize field map\n");
+    NS_IF_RELEASE(m_pFieldMap);
   }
 }
 
 
 NS_IMETHODIMP nsImportGenericAddressBooks::WantsProgress(bool *_retval)
 {
-  NS_PRECONDITION(_retval != nsnull, "null ptr");
+  NS_PRECONDITION(_retval != nullptr, "null ptr");
     if (!_retval)
         return NS_ERROR_NULL_POINTER;
 
   GetDefaultLocation();
   GetDefaultBooks();
 
-  PRUint32    totalSize = 0;
+  uint32_t    totalSize = 0;
   bool        result = false;
 
   if (m_pBooks) {
-    PRUint32    count = 0;
-    nsresult     rv = m_pBooks->Count( &count);
-    PRUint32    i;
+    uint32_t    count = 0;
+    nsresult     rv = m_pBooks->Count(&count);
+    uint32_t    i;
     bool        import;
-    PRUint32    size;
+    uint32_t    size;
 
     for (i = 0; i < count; i++) {
       nsCOMPtr<nsIImportABDescriptor> book =
@@ -485,9 +452,9 @@ NS_IMETHODIMP nsImportGenericAddressBooks::WantsProgress(bool *_retval)
       if (book) {
         import = false;
         size = 0;
-        rv = book->GetImport( &import);
+        rv = book->GetImport(&import);
         if (import) {
-          rv = book->GetSize( &size);
+          rv = book->GetSize(&size);
           result = true;
         }
         totalSize += size;
@@ -501,10 +468,10 @@ NS_IMETHODIMP nsImportGenericAddressBooks::WantsProgress(bool *_retval)
 
   *_retval = result;
 
-  return( NS_OK);
+  return NS_OK;
 }
 
-void nsImportGenericAddressBooks::SetLogs( nsString& success, nsString& error, nsISupportsString *pSuccess, nsISupportsString *pError)
+void nsImportGenericAddressBooks::SetLogs(nsString& success, nsString& error, nsISupportsString *pSuccess, nsISupportsString *pError)
 {
   nsAutoString str;
   if (pSuccess) {
@@ -522,23 +489,23 @@ void nsImportGenericAddressBooks::SetLogs( nsString& success, nsString& error, n
 already_AddRefed<nsIAddrDatabase> GetAddressBookFromUri(const char *pUri)
 {
   if (!pUri)
-    return nsnull;
+    return nullptr;
 
   nsCOMPtr<nsIAbManager> abManager = do_GetService(NS_ABMANAGER_CONTRACTID);
   if (!abManager)
-    return nsnull;
+    return nullptr;
 
   nsCOMPtr<nsIAbDirectory> directory;
   abManager->GetDirectory(nsDependentCString(pUri),
                           getter_AddRefs(directory));
   if (!directory)
-    return nsnull;
+    return nullptr;
 
   nsCOMPtr<nsIAbMDBDirectory> mdbDirectory = do_QueryInterface(directory);
   if (!mdbDirectory)
-    return nsnull;
+    return nullptr;
 
-  nsIAddrDatabase *pDatabase = nsnull;
+  nsIAddrDatabase *pDatabase = nullptr;
   mdbDirectory->GetDatabase(&pDatabase);
   return pDatabase;
 }
@@ -552,11 +519,11 @@ already_AddRefed<nsIAddrDatabase> GetAddressBook(const PRUnichar *name,
     // For now, assume we didn't find anything with that name
   }
 
-  IMPORT_LOG0( "In GetAddressBook\n");
+  IMPORT_LOG0("In GetAddressBook\n");
 
   nsresult rv;
-  nsIAddrDatabase *pDatabase = nsnull;
-  nsCOMPtr<nsILocalFile> dbPath;
+  nsIAddrDatabase *pDatabase = nullptr;
+  nsCOMPtr<nsIFile> dbPath;
   nsCOMPtr<nsIAbManager> abManager = do_GetService(NS_ABMANAGER_CONTRACTID, &rv);
   if (NS_SUCCEEDED(rv))
   {
@@ -573,14 +540,14 @@ already_AddRefed<nsIAddrDatabase> GetAddressBook(const PRUnichar *name,
 
         if (NS_SUCCEEDED(rv))
         {
-          IMPORT_LOG0( "Getting the address database factory\n");
+          IMPORT_LOG0("Getting the address database factory\n");
 
           nsCOMPtr<nsIAddrDatabase> addrDBFactory =
             do_GetService(NS_ADDRDATABASE_CONTRACTID, &rv);
           if (NS_FAILED(rv))
-            return nsnull;
+            return nullptr;
 
-          IMPORT_LOG0( "Opening the new address book\n");
+          IMPORT_LOG0("Opening the new address book\n");
           rv = addrDBFactory->Open(dbPath, true, true,
                                    &pDatabase);
         }
@@ -589,7 +556,7 @@ already_AddRefed<nsIAddrDatabase> GetAddressBook(const PRUnichar *name,
   }
   if (NS_FAILED(rv))
   {
-    IMPORT_LOG0( "Failed to get the user profile directory from the address book session\n");
+    IMPORT_LOG0("Failed to get the user profile directory from the address book session\n");
   }
 
   if (pDatabase && dbPath)
@@ -603,24 +570,24 @@ already_AddRefed<nsIAddrDatabase> GetAddressBook(const PRUnichar *name,
                             getter_AddRefs(parentDir));
     if (parentDir)
     {
-      nsCAutoString URI("moz-abmdbdirectory://");
-      nsCAutoString leafName;
+      nsAutoCString URI("moz-abmdbdirectory://");
+      nsAutoCString leafName;
       rv = dbPath->GetNativeLeafName(leafName);
       if (NS_FAILED(rv))
-        IMPORT_LOG0( "*** Error: Unable to get name of database file\n");
+        IMPORT_LOG0("*** Error: Unable to get name of database file\n");
       else
       {
         URI.Append(leafName);
         rv = parentDir->CreateDirectoryByURI(nsDependentString(name), URI);
         if (NS_FAILED(rv))
-          IMPORT_LOG0( "*** Error: Unable to create address book directory\n");
+          IMPORT_LOG0("*** Error: Unable to create address book directory\n");
       }
     }
 
     if (NS_SUCCEEDED(rv))
-      IMPORT_LOG0( "Added new address book to the UI\n");
+      IMPORT_LOG0("Added new address book to the UI\n");
     else
-      IMPORT_LOG0( "*** Error: An error occurred while adding the address book to the UI\n");
+      IMPORT_LOG0("*** Error: An error occurred while adding the address book to the UI\n");
   }
 
   return pDatabase;
@@ -628,7 +595,7 @@ already_AddRefed<nsIAddrDatabase> GetAddressBook(const PRUnichar *name,
 
 NS_IMETHODIMP nsImportGenericAddressBooks::BeginImport(nsISupportsString *successLog, nsISupportsString *errorLog, bool *_retval)
 {
-  NS_PRECONDITION(_retval != nsnull, "null ptr");
+  NS_PRECONDITION(_retval != nullptr, "null ptr");
     if (!_retval)
         return NS_ERROR_NULL_POINTER;
 
@@ -639,16 +606,16 @@ NS_IMETHODIMP nsImportGenericAddressBooks::BeginImport(nsISupportsString *succes
     *_retval = true;
     nsImportStringBundle::GetStringByID(IMPORT_NO_ADDRBOOKS, m_stringBundle,
                                         success);
-    SetLogs( success, error, successLog, errorLog);
-    return( NS_OK);
+    SetLogs(success, error, successLog, errorLog);
+    return NS_OK;
   }
 
   if (!m_pInterface || !m_pBooks) {
     nsImportStringBundle::GetStringByID(IMPORT_ERROR_AB_NOTINITIALIZED,
                                         m_stringBundle, error);
-    SetLogs( success, error, successLog, errorLog);
+    SetLogs(success, error, successLog, errorLog);
     *_retval = false;
-    return( NS_OK);
+    return NS_OK;
   }
 
   bool needsFieldMap = false;
@@ -662,12 +629,12 @@ NS_IMETHODIMP nsImportGenericAddressBooks::BeginImport(nsISupportsString *succes
     return NS_OK;
   }
 
-  NS_IF_RELEASE( m_pSuccessLog);
-  NS_IF_RELEASE( m_pErrorLog);
+  NS_IF_RELEASE(m_pSuccessLog);
+  NS_IF_RELEASE(m_pErrorLog);
   m_pSuccessLog = successLog;
   m_pErrorLog = errorLog;
-  NS_IF_ADDREF( m_pSuccessLog);
-  NS_IF_ADDREF( m_pErrorLog);
+  NS_IF_ADDREF(m_pSuccessLog);
+  NS_IF_ADDREF(m_pErrorLog);
 
 
   // create the info need to drive address book import. We're
@@ -675,25 +642,25 @@ NS_IMETHODIMP nsImportGenericAddressBooks::BeginImport(nsISupportsString *succes
   // don't tend to be large, and import is rare.
   m_pThreadData = new AddressThreadData();
   m_pThreadData->books = m_pBooks;
-  NS_ADDREF( m_pBooks);
+  NS_ADDREF(m_pBooks);
   m_pThreadData->addressImport = m_pInterface;
-  NS_ADDREF( m_pInterface);
+  NS_ADDREF(m_pInterface);
   m_pThreadData->fieldMap = m_pFieldMap;
-  NS_IF_ADDREF( m_pFieldMap);
+  NS_IF_ADDREF(m_pFieldMap);
   m_pThreadData->errorLog = m_pErrorLog;
-  NS_IF_ADDREF( m_pErrorLog);
+  NS_IF_ADDREF(m_pErrorLog);
   m_pThreadData->successLog = m_pSuccessLog;
-  NS_IF_ADDREF( m_pSuccessLog);
+  NS_IF_ADDREF(m_pSuccessLog);
   if (m_pDestinationUri)
-    m_pThreadData->pDestinationUri = strdup( m_pDestinationUri);
+    m_pThreadData->pDestinationUri = strdup(m_pDestinationUri);
 
-  PRUint32 count = 0;
+  uint32_t count = 0;
   m_pBooks->Count(&count);
   // Create/obtain any address books that we need here, so that we don't need
   // to do so inside the import thread which would just proxy the create
   // operations back to the main thread anyway.
   nsCOMPtr<nsIAddrDatabase> db = GetAddressBookFromUri(m_pDestinationUri);
-  for (PRUint32 i = 0; i < count; ++i)
+  for (uint32_t i = 0; i < count; ++i)
   {
     nsCOMPtr<nsIImportABDescriptor> book = do_QueryElementAt(m_pBooks, i);
     if (book)
@@ -716,15 +683,15 @@ NS_IMETHODIMP nsImportGenericAddressBooks::BeginImport(nsISupportsString *succes
 
   ImportAddressThread(m_pThreadData);
   delete m_pThreadData;
-  m_pThreadData = nsnull;
+  m_pThreadData = nullptr;
   *_retval = true;
 
-  return( NS_OK);
+  return NS_OK;
 }
 
 NS_IMETHODIMP nsImportGenericAddressBooks::ContinueImport(bool *_retval)
 {
-    NS_PRECONDITION(_retval != nsnull, "null ptr");
+    NS_PRECONDITION(_retval != nullptr, "null ptr");
     if (!_retval)
         return NS_ERROR_NULL_POINTER;
 
@@ -734,26 +701,26 @@ NS_IMETHODIMP nsImportGenericAddressBooks::ContinueImport(bool *_retval)
       *_retval = false;
   }
 
-  return( NS_OK);
+  return NS_OK;
 }
 
 
-NS_IMETHODIMP nsImportGenericAddressBooks::GetProgress(PRInt32 *_retval)
+NS_IMETHODIMP nsImportGenericAddressBooks::GetProgress(int32_t *_retval)
 {
   // This returns the progress from the the currently
   // running import mail or import address book thread.
-    NS_PRECONDITION(_retval != nsnull, "null ptr");
+    NS_PRECONDITION(_retval != nullptr, "null ptr");
     if (!_retval)
         return NS_ERROR_NULL_POINTER;
 
   if (!m_pThreadData || !(m_pThreadData->threadAlive)) {
     *_retval = 100;
-    return( NS_OK);
+    return NS_OK;
   }
 
-  PRUint32 sz = 0;
+  uint32_t sz = 0;
   if (m_pThreadData->currentSize && m_pInterface) {
-    if (NS_FAILED( m_pInterface->GetImportProgress( &sz)))
+    if (NS_FAILED(m_pInterface->GetImportProgress(&sz)))
       sz = 0;
   }
 
@@ -771,7 +738,7 @@ NS_IMETHODIMP nsImportGenericAddressBooks::GetProgress(PRInt32 *_retval)
   if (*_retval > 99)
     *_retval = 99;
 
-  return( NS_OK);
+  return NS_OK;
 }
 
 
@@ -779,10 +746,10 @@ NS_IMETHODIMP nsImportGenericAddressBooks::CancelImport(void)
 {
   if (m_pThreadData) {
     m_pThreadData->abort = true;
-    m_pThreadData = nsnull;
+    m_pThreadData = nullptr;
   }
 
-  return( NS_OK);
+  return NS_OK;
 }
 
 
@@ -794,14 +761,14 @@ AddressThreadData::AddressThreadData()
   abort = false;
   currentTotal = 0;
   currentSize = 0;
-  books = nsnull;
-  addressImport = nsnull;
-  successLog = nsnull;
-  errorLog = nsnull;
-  pDestinationUri = nsnull;
-  fieldMap = nsnull;
-  stringBundle = nsnull;
-  ldifService = nsnull;
+  books = nullptr;
+  addressImport = nullptr;
+  successLog = nullptr;
+  errorLog = nullptr;
+  pDestinationUri = nullptr;
+  fieldMap = nullptr;
+  stringBundle = nullptr;
+  ldifService = nullptr;
 }
 
 AddressThreadData::~AddressThreadData()
@@ -824,24 +791,24 @@ void nsImportGenericAddressBooks::ReportError(const PRUnichar *pName,
   if (!pStream)
     return;
   // load the error string
-  PRUnichar *pFmt = nsImportStringBundle::GetStringByID( IMPORT_ERROR_GETABOOK, aBundle);
-  PRUnichar *pText = nsTextFormatter::smprintf( pFmt, pName);
-  pStream->Append( pText);
-  nsTextFormatter::smprintf_free( pText);
+  PRUnichar *pFmt = nsImportStringBundle::GetStringByID(IMPORT_ERROR_GETABOOK, aBundle);
+  PRUnichar *pText = nsTextFormatter::smprintf(pFmt, pName);
+  pStream->Append(pText);
+  nsTextFormatter::smprintf_free(pText);
   NS_Free(pFmt);
   pStream->AppendLiteral(MSG_LINEBREAK);
 }
 
-static void ImportAddressThread( void *stuff)
+static void ImportAddressThread(void *stuff)
 {
-  IMPORT_LOG0( "In Begin ImportAddressThread\n");
+  IMPORT_LOG0("In Begin ImportAddressThread\n");
 
   AddressThreadData *pData = (AddressThreadData *)stuff;
-  PRUint32  count = 0;
-  nsresult   rv = pData->books->Count( &count);
-  PRUint32          i;
+  uint32_t  count = 0;
+  nsresult   rv = pData->books->Count(&count);
+  uint32_t          i;
   bool              import;
-  PRUint32          size;
+  uint32_t          size;
 
   nsString          success;
   nsString          error;
@@ -852,9 +819,9 @@ static void ImportAddressThread( void *stuff)
     if (book) {
       import = false;
       size = 0;
-      rv = book->GetImport( &import);
+      rv = book->GetImport(&import);
       if (import)
-        rv = book->GetSize( &size);
+        rv = book->GetSize(&size);
 
       if (size && import) {
         nsString name;
@@ -865,20 +832,20 @@ static void ImportAddressThread( void *stuff)
         bool fatalError = false;
         pData->currentSize = size;
         if (db) {
-          PRUnichar *pSuccess = nsnull;
-          PRUnichar *pError = nsnull;
+          PRUnichar *pSuccess = nullptr;
+          PRUnichar *pError = nullptr;
 
           /*
           if (pData->fieldMap) {
-            PRInt32    sz = 0;
-            PRInt32    mapIndex;
+            int32_t    sz = 0;
+            int32_t    mapIndex;
             bool      active;
-            pData->fieldMap->GetMapSize( &sz);
-            IMPORT_LOG1( "**** Field Map Size: %d\n", (int) sz);
-            for (PRInt32 i = 0; i < sz; i++) {
-              pData->fieldMap->GetFieldMap( i, &mapIndex);
-              pData->fieldMap->GetFieldActive( i, &active);
-              IMPORT_LOG3( "Field map #%d: index=%d, active=%d\n", (int) i, (int) mapIndex, (int) active);
+            pData->fieldMap->GetMapSize(&sz);
+            IMPORT_LOG1("**** Field Map Size: %d\n", (int) sz);
+            for (int32_t i = 0; i < sz; i++) {
+              pData->fieldMap->GetFieldMap(i, &mapIndex);
+              pData->fieldMap->GetFieldActive(i, &active);
+              IMPORT_LOG3("Field map #%d: index=%d, active=%d\n", (int) i, (int) mapIndex, (int) active);
             }
           }
           */
@@ -891,12 +858,12 @@ static void ImportAddressThread( void *stuff)
                                                        &pSuccess,
                                                        &fatalError);
           if (pSuccess) {
-            success.Append( pSuccess);
-            NS_Free( pSuccess);
+            success.Append(pSuccess);
+            NS_Free(pSuccess);
           }
           if (pError) {
-            error.Append( pError);
-            NS_Free( pError);
+            error.Append(pError);
+            NS_Free(pError);
           }
         }
         else {
@@ -918,7 +885,7 @@ static void ImportAddressThread( void *stuff)
   }
 
 
-  nsImportGenericAddressBooks::SetLogs( success, error, pData->successLog, pData->errorLog);
+  nsImportGenericAddressBooks::SetLogs(success, error, pData->successLog, pData->errorLog);
 
   if (pData->abort || pData->fatalError) {
     // FIXME: do what is necessary to get rid of what has been imported so far.
