@@ -1,40 +1,7 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1/GPL 2.0/LGPL 2.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is mozilla.org code.
- *
- * The Initial Developer of the Original Code is
- * Netscape Communications Corporation.
- * Portions created by the Initial Developer are Copyright (C) 1998
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *   Ben Bucksch <mozilla@bucksch.org>
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either of the GNU General Public License Version 2 or later (the "GPL"),
- * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
- * in which case the provisions of the GPL or the LGPL are applicable instead
- * of those above. If you wish to allow use of your version of this file only
- * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the MPL, indicate your
- * decision by deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL or the LGPL. If you do not delete
- * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the MPL, the GPL or the LGPL.
- *
- * ***** END LICENSE BLOCK ***** */
+/* This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 #include "mimetpfl.h"
 #include "mimebuf.h"
@@ -49,23 +16,23 @@
 #include "prprf.h"
 #include "nsMsgI18N.h"
 
-static const PRUint32 kSpacesForATab = 4; // Must be at least 1.
-static const PRUint32 kInitialBufferSize = 100;
+static const uint32_t kSpacesForATab = 4; // Must be at least 1.
+static const uint32_t kInitialBufferSize = 100;
 
 #define MIME_SUPERCLASS mimeInlineTextClass
 MimeDefClass(MimeInlineTextPlainFlowed, MimeInlineTextPlainFlowedClass,
        mimeInlineTextPlainFlowedClass, &MIME_SUPERCLASS);
 
 static int MimeInlineTextPlainFlowed_parse_begin (MimeObject *);
-static int MimeInlineTextPlainFlowed_parse_line (const char *, PRInt32, MimeObject *);
+static int MimeInlineTextPlainFlowed_parse_line (const char *, int32_t, MimeObject *);
 static int MimeInlineTextPlainFlowed_parse_eof (MimeObject *, bool);
 
-static MimeInlineTextPlainFlowedExData *MimeInlineTextPlainFlowedExDataList = nsnull;
+static MimeInlineTextPlainFlowedExData *MimeInlineTextPlainFlowedExDataList = nullptr;
 
 // From mimetpla.cpp
 extern "C" void MimeTextBuildPrefixCSS(
-                       PRInt32 quotedSizeSetting,      // mail.quoted_size
-                       PRInt32    quotedStyleSetting,  // mail.quoted_style
+                       int32_t quotedSizeSetting,      // mail.quoted_size
+                       int32_t    quotedStyleSetting,  // mail.quoted_style
                        char       *citationColor,      // mail.citation_color
                        nsACString &style);
 // Definition below
@@ -144,7 +111,7 @@ MimeInlineTextPlainFlowed_parse_begin (MimeObject *obj)
   //  Quotes
   text->mQuotedSizeSetting = 0;   // mail.quoted_size
   text->mQuotedStyleSetting = 0;  // mail.quoted_style
-  text->mCitationColor = nsnull;  // mail.citation_color
+  text->mCitationColor = nullptr;  // mail.citation_color
 
   nsIPrefBranch *prefBranch = GetPrefBranch(obj->options);
   if (prefBranch)
@@ -160,8 +127,8 @@ MimeInlineTextPlainFlowed_parse_begin (MimeObject *obj)
 
   // Get font
   // only used for viewing (!plainHTML)
-  nsCAutoString fontstyle;
-  nsCAutoString fontLang;     // langgroup of the font
+  nsAutoCString fontstyle;
+  nsAutoCString fontLang;     // langgroup of the font
 
 
   // generic font-family name ( -moz-fixed for fixed font and NULL for
@@ -173,8 +140,8 @@ MimeInlineTextPlainFlowed_parse_begin (MimeObject *obj)
   if (nsMimeOutput::nsMimeMessageBodyDisplay == obj->options->format_out ||
       nsMimeOutput::nsMimeMessagePrintOutput == obj->options->format_out)
   {
-    PRInt32 fontSize;       // default font size
-    PRInt32 fontSizePercentage;   // size percentage
+    int32_t fontSize;       // default font size
+    int32_t fontSizePercentage;   // size percentage
     nsresult rv = GetMailNewsFont(obj, exdata->fixedwidthfont,
                                   &fontSize, &fontSizePercentage, fontLang);
     if (NS_SUCCEEDED(rv))
@@ -193,7 +160,7 @@ MimeInlineTextPlainFlowed_parse_begin (MimeObject *obj)
        /* 4.x' editor can't break <div>s (e.g. to interleave comments).
           We'll add the class to the <blockquote type=cite> later. */
   {
-    nsCAutoString openingDiv("<div class=\"moz-text-flowed\"");
+    nsAutoCString openingDiv("<div class=\"moz-text-flowed\"");
     // We currently have to add formatting here. :-(
     if (!plainHTML && !fontstyle.IsEmpty())
     {
@@ -219,7 +186,7 @@ static int
 MimeInlineTextPlainFlowed_parse_eof (MimeObject *obj, bool abort_p)
 {
   int status = 0;
-  struct MimeInlineTextPlainFlowedExData *exdata = nsnull;
+  struct MimeInlineTextPlainFlowedExData *exdata = nullptr;
 
   bool quoting = ( obj->options
     && ( obj->options->format_out == nsMimeOutput::nsMimeMessageQuoting ||
@@ -240,7 +207,7 @@ MimeInlineTextPlainFlowed_parse_eof (MimeObject *obj, bool abort_p)
   struct MimeInlineTextPlainFlowedExData **prevexdata;
   prevexdata = &MimeInlineTextPlainFlowedExDataList;
 
-  while ((exdata = *prevexdata) != nsnull) {
+  while ((exdata = *prevexdata) != nullptr) {
     if (exdata->ownerobj == obj) {
       // Fill hole
       *prevexdata = exdata->next;
@@ -278,14 +245,14 @@ EarlyOut:
   // Free mCitationColor
   MimeInlineTextPlainFlowed *text = (MimeInlineTextPlainFlowed *) obj;
   PR_FREEIF(text->mCitationColor);
-  text->mCitationColor = nsnull;
+  text->mCitationColor = nullptr;
 
   return status;
 }
 
 
 static int
-MimeInlineTextPlainFlowed_parse_line (const char *aLine, PRInt32 length, MimeObject *obj)
+MimeInlineTextPlainFlowed_parse_line (const char *aLine, int32_t length, MimeObject *obj)
 {
   int status;
   bool quoting = ( obj->options
@@ -308,7 +275,7 @@ MimeInlineTextPlainFlowed_parse_line (const char *aLine, PRInt32 length, MimeObj
   if (length <= 0) return 0;
 
   uint32 linequotelevel = 0;
-  nsCAutoString real_line(aLine, length);
+  nsAutoCString real_line(aLine, length);
   char *line = real_line.BeginWriting();
   const char *linep = real_line.BeginReading();
   // Space stuffed?
@@ -333,7 +300,7 @@ MimeInlineTextPlainFlowed_parse_line (const char *aLine, PRInt32 length, MimeObj
   // be the case always.
   bool flowed = false;
   bool sigSeparator = false;
-  PRInt32 index = length-1;
+  int32_t index = length-1;
   while(index >= 0 && ('\r' == line[index] || '\n' == line[index])) {
     index--;
   }
@@ -371,7 +338,7 @@ MimeInlineTextPlainFlowed_parse_line (const char *aLine, PRInt32 length, MimeObj
     // Convert only if the source string is not empty
     if (length - (linep - line) > 0)
     {
-      PRUint32 whattodo = obj->options->whattodo;
+      uint32_t whattodo = obj->options->whattodo;
       if (plainHTML)
       {
         if (quoting)
@@ -416,7 +383,7 @@ MimeInlineTextPlainFlowed_parse_line (const char *aLine, PRInt32 length, MimeObj
     status = NS_OK;
   }
 
-  nsCAutoString preface;
+  nsAutoCString preface;
 
   /* Correct number of blockquotes */
   int32 quoteleveldiff=linequotelevel - exdata->quotelevel;
@@ -434,7 +401,7 @@ MimeInlineTextPlainFlowed_parse_line (const char *aLine, PRInt32 length, MimeObj
     // This is to have us observe the user pref settings for citations
     MimeInlineTextPlainFlowed *tObj = (MimeInlineTextPlainFlowed *) obj;
 
-    nsCAutoString style;
+    nsAutoCString style;
     MimeTextBuildPrefixCSS(tObj->mQuotedSizeSetting, tObj->mQuotedStyleSetting,
                            tObj->mCitationColor, style);
     if (!plainHTML && !style.IsEmpty())
@@ -487,7 +454,7 @@ MimeInlineTextPlainFlowed_parse_line (const char *aLine, PRInt32 length, MimeObj
   {
     status = MimeObject_write(obj, preface.get(), preface.Length(), true);
     if (status < 0) return status;
-    nsCAutoString outString;
+    nsAutoCString outString;
     if (obj->options->format_out != nsMimeOutput::nsMimeMessageSaveAs ||
         !mailCharset || !*mailCharset)
       CopyUTF16toUTF8(lineResult2, outString);
@@ -582,8 +549,8 @@ static void Convert_whitespace(const PRUnichar a_current_char,
   NS_ASSERTION('\t' == a_current_char || ' ' == a_current_char,
                "Convert_whitespace got something else than a whitespace!");
 
-  PRUint32 number_of_nbsp = 0;
-  PRUint32 number_of_space = 1; // Assume we're going to output one space.
+  uint32_t number_of_nbsp = 0;
+  uint32_t number_of_space = 1; // Assume we're going to output one space.
 
   /* Output the spaces for a tab. All but the last are made into &nbsp;.
      The last is treated like a normal space.
@@ -626,7 +593,7 @@ nsresult Line_convert_whitespace(const nsString& a_line,
   bool in_quote_in_tag = false;
   PRUnichar quote_char;
 
-  for (PRUint32 i = 0; a_line.Length() > i; i++)
+  for (uint32_t i = 0; a_line.Length() > i; i++)
   {
     const PRUnichar ic = a_line[i];  // Cache
 
