@@ -1,46 +1,22 @@
 /* -*- Mode: javascript; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1/GPL 2.0/LGPL 2.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is mozilla.org code.
- *
- * The Initial Developer of the Original Code is
- * Netscape Communications Corporation.
- * Portions created by the Initial Developer are Copyright (C) 1998
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *   Benjamin Smedberg <bsmedberg@covad.net>
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either of the GNU General Public License Version 2 or later (the "GPL"),
- * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
- * in which case the provisions of the GPL or the LGPL are applicable instead
- * of those above. If you wish to allow use of your version of this file only
- * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the MPL, indicate your
- * decision by deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL or the LGPL. If you do not delete
- * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the MPL, the GPL or the LGPL.
- *
- * ***** END LICENSE BLOCK ***** */
+/* This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 /* The prefs in this file are specific to the seamonkey (toolkit) browser.
  * Generic default prefs that would be useful to embedders belong in
  * modules/libpref/src/init/all.js
  */
 
+/* filter substitution
+ *
+ * SYNTAX HINTS:
+ *
+ *  - Dashes are delimiters; use underscores instead.
+ *  - The first character after a period must be alphabetic.
+ *  - Computed values (e.g. 50 * 1024) don't work.
+ */
+
 pref("startup.homepage_override_url","chrome://navigator-region/locale/region.properties");
 pref("general.skins.selectedSkin", "classic/1.0");
 
@@ -65,7 +41,9 @@ pref("general.autoScroll", true);
 
 pref("general.useragent.compatMode.firefox", true);
 
-// 0 = blank, 1 = home (browser.startup.homepage), 2 = last
+pref("general.useragent.complexOverride.moodle", false); // bug 797703; bug 815801
+
+// 0 = blank, 1 = home (browser.startup.homepage), 2 = last visited page, 3 = resume previous browser session
 pref("browser.startup.page",                1);
 pref("browser.startup.homepage",	   "chrome://navigator-region/locale/region.properties");
 pref("browser.startup.homepage.count", 1);
@@ -103,6 +81,9 @@ pref("browser.download.progress.closeWhenDone", false);
 // feedback from their action.
 pref("browser.download.saveLinkAsFilenameTimeout", 4000);
 
+// Output console.log/info/warn/error to the Error Console
+pref("browser.dom.window.console.enabled", false);
+
 // Use the findbar instead of the dialog box
 pref("browser.findbar.enabled", true);
 
@@ -150,6 +131,7 @@ pref("keyword.enabled", true);
 pref("keyword.URL", "");
 
 pref("browser.urlbar.autocomplete.enabled", true);
+pref("browser.urlbar.formatting.enabled", true);
 pref("browser.urlbar.clickSelectsAll", true);
 // when clickSelectsAll=true, does it also apply when the click is past end of text?
 pref("browser.urlbar.clickAtEndSelects", true);
@@ -343,8 +325,18 @@ pref("browser.offline-apps.notify", true);
 
 pref("browser.formfill.expire_days",        180);
 
+pref("mail.biff.alert.show_preview", true);
+pref("mail.biff.alert.show_subject", true);
+pref("mail.biff.alert.show_sender",  true);
+pref("mail.biff.alert.preview_length", 40);
+
 pref("mailnews.ui.deleteMarksRead", true);
 
+// The maximum amount of decoded image data we'll willingly keep around (we
+// might keep around more than this, but we'll try to get down to this value).
+// (This is intentionally on the high side; see bugs 746055 and 768015.)
+pref("image.mem.max_decoded_image_kb", 256000);
+
 pref("spellchecker.dictionaries.download.url", "chrome://branding/locale/brand.properties");
 
 // this will automatically enable inline spellchecking (if it is available) for
@@ -667,16 +659,6 @@ pref("privacy.item.offlineApps", false);
 pref("privacy.sanitize.sanitizeOnShutdown", false);
 pref("privacy.sanitize.promptOnSanitize", true);
 
-/* mousewheel.withcontrolkey.action:
- * 0 = lines
- * 1 = pages
- * 2 = history
- * 3 = text or full zoom depending on "browser.zoom.full".
- */
-pref("mousewheel.withcontrolkey.action",3);
-pref("mousewheel.withcontrolkey.sysnumlines",false);
-pref("mousewheel.withcontrolkey.numlines",1);
-
 // Show XUL error pages instead of alerts for errors
 pref("browser.xul.error_pages.enabled", true);
 pref("browser.xul.error_pages.expert_bad_cert", false);
@@ -694,6 +676,8 @@ pref("dom.disable_window_flip",        true);
 // prevent JS from disabling or replacing context menus
 pref("dom.event.contextmenu.enabled",  true);
 
+pref("dom.identity.enabled", false);
+
 // The default for this pref reflects whether the build is capable of IPC.
 // (Turning it on in a no-IPC build will have no effect.)
 #ifdef XP_MACOSX
@@ -719,11 +703,12 @@ pref("dom.ipc.plugins.enabled", true);
 
 // plugin finder service url
 pref("pfs.datasource.url", "https://pfs.mozilla.org/plugins/PluginFinderService.php?mimetype=%PLUGIN_MIMETYPE%&appID=%APP_ID%&appVersion=%APP_VERSION%&clientOS=%CLIENT_OS%&chromeLocale=%CHROME_LOCALE%");
-pref("plugins.update.url", "http://www.mozilla.com/%LOCALE%/plugincheck/");
+pref("plugins.update.url", "https://www.mozilla.org/%LOCALE%/plugincheck/");
 pref("plugins.update.notifyUser", false);
 pref("plugins.hide_infobar_for_outdated_plugin", false);
 pref("plugins.hide_infobar_for_carbon_failure_plugin", false);
 pref("plugins.hide_infobar_for_missing_plugin", false);
+pref("plugins.click_to_play", false);
 pref("plugin.disable", false);
 
 #ifdef XP_MACOSX
@@ -807,6 +792,7 @@ pref("services.sync.prefs.sync.browser.formfill.enable", true);
 pref("services.sync.prefs.sync.browser.link.open_external", true);
 pref("services.sync.prefs.sync.browser.link.open_newwindow", true);
 pref("services.sync.prefs.sync.browser.search.update", true);
+pref("services.sync.prefs.sync.browser.sessionstore.max_concurrent_tabs", true);
 pref("services.sync.prefs.sync.browser.startup.homepage", true);
 pref("services.sync.prefs.sync.browser.startup.page", true);
 pref("services.sync.prefs.sync.browser.tabs.autoHide", true);
@@ -831,6 +817,55 @@ pref("services.sync.prefs.sync.javascript.enabled", true);
 pref("services.sync.prefs.sync.layout.spellcheckDefault", true);
 pref("services.sync.prefs.sync.lightweightThemes.isThemeSelected", true);
 pref("services.sync.prefs.sync.lightweightThemes.usedThemes", true);
+pref("services.sync.prefs.sync.mailnews.confirm.moveFoldersToTrash", true);
+pref("services.sync.prefs.sync.mailnews.customDBHeaders", true);
+pref("services.sync.prefs.sync.mailnews.customHeaders", true);
+pref("services.sync.prefs.sync.mailnews.display.date_senders_timezone", true);
+pref("services.sync.prefs.sync.mailnews.display.disable_format_flowed_support", true);
+pref("services.sync.prefs.sync.mailnews.display.disallow_mime_handlers", true);
+pref("services.sync.prefs.sync.mailnews.display.html_as", true);
+pref("services.sync.prefs.sync.mailnews.display.html_sanitizer.allowed_tags", true);
+pref("services.sync.prefs.sync.mailnews.display.prefer_plaintext", true);
+pref("services.sync.prefs.sync.mailnews.display.show_all_body_parts_menu", true);
+pref("services.sync.prefs.sync.mailnews.emptyTrash.dontAskAgain", true);
+pref("services.sync.prefs.sync.mailnews.filters.confirm_delete", true);
+pref("services.sync.prefs.sync.mailnews.headers.extraExpandedHeaders", true);
+pref("services.sync.prefs.sync.mailnews.headers.showMessageId", true);
+pref("services.sync.prefs.sync.mailnews.headers.showOrganization", true);
+pref("services.sync.prefs.sync.mailnews.headers.showReferences", true);
+pref("services.sync.prefs.sync.mailnews.headers.showSender", true);
+pref("services.sync.prefs.sync.mailnews.headers.showUserAgent", true);
+pref("services.sync.prefs.sync.mailnews.localizedRe", true);
+pref("services.sync.prefs.sync.mailnews.mark_message_read.auto", true);
+pref("services.sync.prefs.sync.mailnews.mark_message_read.delay", true);
+pref("services.sync.prefs.sync.mailnews.mark_message_read.delay.interval", true);
+pref("services.sync.prefs.sync.mailnews.messageid.openInNewWindow", true);
+pref("services.sync.prefs.sync.mailnews.message_display.allow_plugins", true);
+pref("services.sync.prefs.sync.mailnews.message_display.disable_remote_image", true);
+pref("services.sync.prefs.sync.mailnews.nav_crosses_folders", true);
+pref("services.sync.prefs.sync.mailnews.offline_sync_mail", true);
+pref("services.sync.prefs.sync.mailnews.offline_sync_news", true);
+pref("services.sync.prefs.sync.mailnews.offline_sync_send_unsent", true);
+pref("services.sync.prefs.sync.mailnews.offline_sync_work_offline", true);
+pref("services.sync.prefs.sync.mailnews.remember_selected_message", true);
+pref("services.sync.prefs.sync.mailnews.reply_header_authorwrote", true);
+pref("services.sync.prefs.sync.mailnews.reply_header_colon", true);
+pref("services.sync.prefs.sync.mailnews.reply_header_locale", true);
+pref("services.sync.prefs.sync.mailnews.reply_header_ondate", true);
+pref("services.sync.prefs.sync.mailnews.reply_header_originalmessage", true);
+pref("services.sync.prefs.sync.mailnews.reply_header_separator", true);
+pref("services.sync.prefs.sync.mailnews.reply_header_type", true);
+pref("services.sync.prefs.sync.mailnews.scroll_to_new_message", true);
+pref("services.sync.prefs.sync.mailnews.sendInBackground", true);
+pref("services.sync.prefs.sync.mailnews.send_default_charset", true);
+pref("services.sync.prefs.sync.mailnews.send_plaintext_flowed", true);
+pref("services.sync.prefs.sync.mailnews.show_send_progress", true);
+pref("services.sync.prefs.sync.mailnews.start_page.enabled", true);
+pref("services.sync.prefs.sync.mailnews.thread_pane_column_unthreads", true);
+pref("services.sync.prefs.sync.mailnews.ui.deleteMarksRead", true);
+pref("services.sync.prefs.sync.mailnews.ui.junk.manualMarkAsJunkMarksRead", true);
+pref("services.sync.prefs.sync.mailnews.view_default_charset", true);
+pref("services.sync.prefs.sync.mailnews.wraplength", true);
 pref("services.sync.prefs.sync.network.cookie.cookieBehavior", true);
 pref("services.sync.prefs.sync.network.cookie.lifetimePolicy", true);
 pref("services.sync.prefs.sync.permissions.default.image", true);
