@@ -1,42 +1,7 @@
 /* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1/GPL 2.0/LGPL 2.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is the Places Bookmark Properties dialog.
- *
- * The Initial Developer of the Original Code is Google Inc.
- * Portions created by the Initial Developer are Copyright (C) 2006
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *   Joe Hughes <jhughes@google.com>
- *   Dietrich Ayala <dietrich@mozilla.com>
- *   Asaf Romano <mano@mozilla.com>
- *   Marco Bonardo <mak77@bonardo.net>
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either the GNU General Public License Version 2 or later (the "GPL"), or
- * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
- * in which case the provisions of the GPL or the LGPL are applicable instead
- * of those above. If you wish to allow use of your version of this file only
- * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the MPL, indicate your
- * decision by deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL or the LGPL. If you do not delete
- * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the MPL, the GPL or the LGPL.
- *
- * ***** END LICENSE BLOCK ***** */
+/* This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 /**
  * The panel is initialized based on data given in the js object passed
@@ -346,17 +311,18 @@ var BookmarkPropertiesPanel = {
     // resize the dialog.
     var prefs = Components.classes["@mozilla.org/preferences-service;1"]
                           .getService(Components.interfaces.nsIPrefBranch);
+    var observer = new MutationObserver(this);
     if (!this._element("tagsRow").collapsed) {
       if (prefs.getBoolPref("browser.bookmarks.editDialog.expandTags"))
         gEditItemOverlay.toggleTagsSelector();
-      this._element("tagsSelectorRow")
-          .addEventListener("DOMAttrModified", this, false);
+      observer.observe(this._element("tagsSelectorRow"),
+                       {attributes: true, attributeFilter: ["collapsed"]});
     }
     if (!this._element("folderRow").collapsed) {
       if (prefs.getBoolPref("browser.bookmarks.editDialog.expandFolders"))
         gEditItemOverlay.toggleFolderTreeVisibility();
-      this._element("folderTreeRow")
-          .addEventListener("DOMAttrModified", this, false);
+      observer.observe(this._element("folderTreeRow"),
+                       {attributes: true, attributeFilter: ["collapsed"]});
     }
 
     if (!this._readOnly) {
@@ -382,7 +348,6 @@ var BookmarkPropertiesPanel = {
   },
 
   // nsIDOMEventListener
-  _elementsHeight: [],
   handleEvent: function BPP_handleEvent(aEvent) {
     var target = aEvent.target;
     switch (aEvent.type) {
@@ -404,20 +369,6 @@ var BookmarkPropertiesPanel = {
             el.height = el.boxObject.height;
         });
         break;
-
-      case "DOMAttrModified":
-        // this is called when collapsing a node, but also its direct children,
-        // we only need to resize when the original node changes.
-        if ((target.id == "editBMPanel_tagsSelectorRow" ||
-             target.id == "editBMPanel_folderTreeRow") &&
-            aEvent.attrName == "collapsed" &&
-            target == aEvent.originalTarget) {
-          var el = document.getElementById("editBookmarkPanelContent");
-          var width = el.boxObject.width;
-          window.sizeToContent();
-          window.outerWidth -= el.boxObject.width - width;
-        }
-        break;
     }
   },
 
@@ -435,6 +386,14 @@ var BookmarkPropertiesPanel = {
     }
   },
 
+  // nsIMutationObserverCallback
+  handleMutations: function BPP_handleMutations(aRecords, aObserver) {
+    var el = document.getElementById("editBookmarkPanelContent");
+    var width = el.boxObject.width;
+    window.sizeToContent();
+    window.outerWidth -= el.boxObject.width - width;
+  },
+
   _beginBatch: function BPP__beginBatch() {
     if (this._batching)
       return;
@@ -474,6 +433,7 @@ var BookmarkPropertiesPanel = {
   QueryInterface: function BPP_QueryInterface(aIID) {
     if (aIID.equals(Components.interfaces.nsIDOMEventListener) ||
         aIID.equals(Components.interfaces.mozILivemarkCallback) ||
+        aIID.equals(Components.interfaces.nsIMutationObserverCallback) ||
         aIID.equals(Components.interfaces.nsISupports))
       return this;
 
@@ -489,10 +449,6 @@ var BookmarkPropertiesPanel = {
     // gEditItemOverlay does not exist anymore here, so don't rely on it.
     // Calling removeEventListener with arguments which do not identify any
     // currently registered EventListener on the EventTarget has no effect.
-    this._element("tagsSelectorRow")
-        .removeEventListener("DOMAttrModified", this, false);
-    this._element("folderTreeRow")
-        .removeEventListener("DOMAttrModified", this, false);
     this._element("locationField")
         .removeEventListener("input", this, false);
     this._element("feedLocationField")
@@ -587,7 +543,7 @@ var BookmarkPropertiesPanel = {
    */
   _getCreateNewBookmarkTransaction:
   function BPP__getCreateNewBookmarkTransaction(aContainer, aIndex) {
-    var nsIAnnotationService = Components.interfaces.nsIAnnotationService;
+    const nsIAnnotationService = Components.interfaces.nsIAnnotationService;
     var annotations = [];
     var childTransactions = [];
 
