@@ -107,19 +107,12 @@ function FillMailContextMenu(aTarget)
   var oneOrMore = (numSelected > 0);
   var single = (numSelected == 1);
 
-  var isNewsgroup = false;
-  var selectedMessage = null;
+  var isNewsgroup = gFolderDisplay.selectedMessageIsNews;
 
   // Clear the global var used to keep track if a 'Delete Message' or 'Move
   // To' command has been triggered via the thread pane context menu.
   gThreadPaneDeleteOrMoveOccurred = false;
 
-  if (numSelected >= 0)
-  {
-    selectedMessage = GetFirstSelectedMessage();
-    isNewsgroup = IsNewsMessage(selectedMessage);
-  }
-
   // Don't show mail items for links/images, just show related items.
   var showMailItems = inThreadPane ||
                       (!gContextMenu.onImage && !gContextMenu.onLink);
@@ -415,11 +408,11 @@ function ShowSeparator(aSeparatorID)
 }
 
 // message pane context menu helper methods
-function AddNodeToAddressBook(emailAddressNode)
+function AddContact(aEmailAddressNode)
 {
-  if (emailAddressNode)
-    AddEmailToAddressBook(emailAddressNode.getAttribute("emailAddress"),
-                          emailAddressNode.getAttribute("displayName"));
+  if (aEmailAddressNode)
+    AddEmailToAddressBook(aEmailAddressNode.getAttribute("emailAddress"),
+                          aEmailAddressNode.getAttribute("displayName"));
 }
 
 function AddEmailToAddressBook(primaryEmail, displayName)
@@ -429,6 +422,17 @@ function AddEmailToAddressBook(primaryEmail, displayName)
                       {primaryEmail:primaryEmail, displayName:displayName});
 }
 
+function EditContact(aEmailAddressNode)
+{
+  if (aEmailAddressNode.cardDetails.card)
+  {
+    window.openDialog("chrome://messenger/content/addressbook/abEditCardDialog.xul",
+                      "", "chrome,resizable=no,modal,titlebar,centerscreen",
+                      { abURI: aEmailAddressNode.cardDetails.book.URI,
+                        card: aEmailAddressNode.cardDetails.card });
+  }
+}
+
 // SendMailToNode takes the email address title button, extracts
 // the email address we stored in there and opens a compose window
 // with that address
@@ -681,7 +685,8 @@ function CopyMessageUrl()
     var hdr = gDBView.hdrForFirstSelectedMessage;
     var server = hdr.folder.server;
 
-    var url = (server.socketType == Components.interfaces.nsIMsgIncomingServer.useSSL) ?
+    // TODO let backend construct URL and return as attribute
+    var url = (server.socketType == Components.interfaces.nsMsgSocketType.SSL) ?
               "snews://" : "news://";
     url += server.hostName + ":" + server.port + "/" + hdr.messageId;
     CopyString(url);
@@ -696,5 +701,5 @@ function CopyString(aString)
 {
   Components.classes["@mozilla.org/widget/clipboardhelper;1"]
             .getService(Components.interfaces.nsIClipboardHelper)
-            .copyString(aString);
+            .copyString(aString, document);
 }
